@@ -22,7 +22,7 @@
 #define BAD_ARGUMENT 1
 #define KLOGEXIT(code) exit(code)
 
-static int CommandProc(struct cmd_syndesc *, void *);
+int CommandProc();
 
 static int zero_argc;
 static char **zero_argv;
@@ -40,7 +40,7 @@ void main (argc, argv)
     /* Start up sockets */
     WSAStartup(0x0101, &WSAjunk);
 
-    ts = cmd_CreateSyntax(NULL, CommandProc, NULL, "obtain Kerberos authentication");
+    ts = cmd_CreateSyntax((char *) 0, CommandProc, 0, "obtain Kerberos authentication");
 
 #define aXFLAG 0
 #define aPRINCIPAL 1
@@ -97,7 +97,7 @@ static int good_gets (s, max)
 	if (feof(stdin)) return EOF;	/* EOF on input, nothing read */
 	else return -2;			/* I don't think this can happen */
     }
-    l = strlen (s);
+    l = (int)strlen (s);
     if (l && (s[l-1] == '\n')) s[--l] = 0;
     return l;
 }
@@ -135,8 +135,9 @@ static int read_pw_string(char *s, int max)
     return !ok;
 }
 
-static int
-CommandProc (struct cmd_syndesc *as, void *arock)
+CommandProc (as, arock)
+  char *arock;
+  struct cmd_syndesc *as;
 {
     char  name[MAXKTCNAMELEN];
     char  instance[MAXKTCNAMELEN];
@@ -310,7 +311,7 @@ bad_lifetime:
        code = krb_write_ticket_file (realm);
        if (!Silent) {
           if (code) 
-              afs_com_err (rn, code, "writing Kerberos ticket file");
+              com_err (rn, code, "writing Kerberos ticket file");
           else fprintf (stderr, "Wrote ticket file to /tmp\n");
       }
    }
