@@ -17,19 +17,14 @@
 #include <malloc.h>
 #include <osi.h>
 #include <rx/rx.h>
-#ifndef DJGPP
 #include <rx/rxkad.h>
-#else
-#include <rx/rxkad.h>
-#endif
-
 #include "afsd.h"
 
 osi_rwlock_t cm_connLock;
 
 long RDRtimeout = CM_CONN_DEFAULTRDRTIMEOUT;
-long ConnDeadtimeout = CM_CONN_CONNDEADTIME;
-long HardDeadtimeout = CM_CONN_HARDDEADTIME;
+unsigned short ConnDeadtimeout = CM_CONN_CONNDEADTIME;
+unsigned short HardDeadtimeout = CM_CONN_HARDDEADTIME;
 
 #define LANMAN_WKS_PARAM_KEY "SYSTEM\\CurrentControlSet\\Services\\lanmanworkstation\\parameters"
 #define LANMAN_WKS_SESSION_TIMEOUT "SessTimeout"
@@ -90,7 +85,7 @@ void cm_InitReq(cm_req_t *reqp)
 {
 	memset((char *)reqp, 0, sizeof(cm_req_t));
 #ifndef DJGPP
-	reqp->startTime = GetCurrentTime();
+	reqp->startTime = GetTickCount();
 #else
         gettimeofday(&reqp->startTime, NULL);
 #endif
@@ -146,15 +141,17 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
     cm_server_t *serverp = NULL;
     cm_serverRef_t **serverspp = NULL;
     cm_serverRef_t *tsrp;
+    cm_cell_t  *cellp = NULL;
     cm_ucell_t *ucellp;
     int retry = 0;
     int free_svr_list = 0;
     int dead_session;
     long timeUsed, timeLeft;
     long code;
-        
-    osi_Log2(afsd_logp, "cm_Analyze connp 0x%x, code 0x%x",
-             (long) connp, errorCode);
+    char addr[16];
+
+    osi_Log2(afsd_logp, "cm_Analyze connp 0x%p, code 0x%x",
+             connp, errorCode);
 
     /* no locking required, since connp->serverp never changes after
      * creation */
@@ -188,7 +185,7 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
     
     /* timeleft - get if from reqp the same way as cmXonnByMServers does */
 #ifndef DJGPP
-    timeUsed = (GetCurrentTime() - reqp->startTime) / 1000;
+    timeUsed = (GetTickCount() - reqp->startTime) / 1000;
 #else
     gettimeofday(&now, NULL);
     timeUsed = sub_time(now, reqp->startTime) / 1000;
@@ -200,7 +197,16 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
     if (errorCode == CM_ERROR_TIMEDOUT) {
         if (timeLeft > 5 ) {
             thrd_Sleep(3000);
-            cm_CheckServers(CM_FLAG_CHECKDOWNSERVERS, NULL);
+            if (cellp == NULL && serverp)
+                cellp = serverp->cellp;
+            if (cellp == NULL && serversp) {
+                struct cm_serverRef * refp;
+                for ( refp=serversp ; cellp == NULL && refp != NULL; refp=refp->next) {
+                    if ( refp->server )
+                        cellp = refp->server->cellp;
+                }
+            }
+            cm_CheckServers(CM_FLAG_CHECKDOWNSERVERS, cellp);
             retry = 1;
         }
     } 
@@ -212,8 +218,8 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
      * until the timeout period expires.
      */
     else if (errorCode == CM_ERROR_NOSUCHVOLUME) {
+	osi_Log0(afsd_logp, "cm_Analyze passed CM_ERROR_NOSUCHVOLUME.");
         if (timeLeft > 7) {
-            osi_Log0(afsd_logp, "cm_Analyze passed CM_ERROR_NOSUCHVOLUME.");
             thrd_Sleep(5000);
             
             retry = 1;
@@ -223,47 +229,57 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
         }
     }
 
+    else if (errorCode == CM_ERROR_ALLDOWN) {
+	osi_Log0(afsd_logp, "cm_Analyze passed CM_ERROR_ALLDOWN.");
+	/* Servers marked DOWN will be restored by the background daemon
+	 * thread as they become available.
+	 */
+    }
+
     else if (errorCode == CM_ERROR_ALLOFFLINE) {
         if (timeLeft > 7) {
             osi_Log0(afsd_logp, "cm_Analyze passed CM_ERROR_ALLOFFLINE.");
             thrd_Sleep(5000);
             
-            /* cm_ForceUpdateVolume marks all servers as non_busy */
-            /* No it doesn't and it won't do anything if all of the 
-             * the servers are marked as DOWN.  So clear the DOWN
-             * flag and reset the busy state as well.
-             */
-            if (!serversp) {
-                code = cm_GetServerList(fidp, userp, reqp, &serverspp);
-                if (code == 0) {
-                    serversp = *serverspp;
-                    free_svr_list = 1;
-                }
-            }
-            if (serversp) {
-                lock_ObtainWrite(&cm_serverLock);
-                for (tsrp = serversp; tsrp; tsrp=tsrp->next) {
-                    tsrp->server->flags &= ~CM_SERVERFLAG_DOWN;
-                    if (tsrp->status == busy)
-                        tsrp->status = not_busy;
-                }
-                lock_ReleaseWrite(&cm_serverLock);
-                if (free_svr_list) {
-                    cm_FreeServerList(&serversp);
-                    *serverspp = serversp;
-                }
-                retry = 1;
-            }
+	    if (fidp) {	/* Not a VLDB call */
+		if (!serversp) {
+		    code = cm_GetServerList(fidp, userp, reqp, &serverspp);
+		    if (code == 0) {
+			serversp = *serverspp;
+			free_svr_list = 1;
+		    }
+		}
+		if (serversp) {
+		    lock_ObtainWrite(&cm_serverLock);
+		    for (tsrp = serversp; tsrp; tsrp=tsrp->next)
+			tsrp->status = not_busy;
+		    lock_ReleaseWrite(&cm_serverLock);
+		    if (free_svr_list) {
+			cm_FreeServerList(&serversp);
+			*serverspp = serversp;
+		    }
+		    retry = 1;
+		}
 
-            if (fidp != NULL)   /* Not a VLDB call */
                 cm_ForceUpdateVolume(fidp, userp, reqp);
-			else
-				retry = 0;
+	    } else { /* VLDB call */
+		if (serversp) {
+		    lock_ObtainWrite(&cm_serverLock);
+		    for (tsrp = serversp; tsrp; tsrp=tsrp->next)
+			tsrp->status = not_busy;
+		    lock_ReleaseWrite(&cm_serverLock);
+		    if (free_svr_list) {
+			cm_FreeServerList(&serversp);
+			*serverspp = serversp;
+		    }
+		}
+	    }	
         }
     }
 
     /* if all servers are busy, mark them non-busy and start over */
     else if (errorCode == CM_ERROR_ALLBUSY) {
+	osi_Log0(afsd_logp, "cm_Analyze passed CM_ERROR_ALLBUSY.");
         if (timeLeft > 7) {
             thrd_Sleep(5000);
             if (!serversp) {
@@ -316,30 +332,62 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
     else if (errorCode == VNOVOL || errorCode == VMOVED || errorCode == VOFFLINE ||
              errorCode == VSALVAGE || errorCode == VNOSERVICE || errorCode == VIO) 
     {       
-        /* Log server being offline for this volume */
-        osi_Log4(afsd_logp, "cm_Analyze found server %d.%d.%d.%d marked offline for a volume",
-                  ((serverp->addr.sin_addr.s_addr & 0xff)),
-                  ((serverp->addr.sin_addr.s_addr & 0xff00)>> 8),
-                  ((serverp->addr.sin_addr.s_addr & 0xff0000)>> 16),
-                  ((serverp->addr.sin_addr.s_addr & 0xff000000)>> 24));
-        /* Create Event Log message */ 
-        {
-            HANDLE h;
-            char *ptbuf[1];
-            char s[100];
-            h = RegisterEventSource(NULL, AFS_DAEMON_EVENT_NAME);
-            sprintf(s, "cm_Analyze: Server %d.%d.%d.%d reported volume %d as missing.",
-                     ((serverp->addr.sin_addr.s_addr & 0xff)),
-                     ((serverp->addr.sin_addr.s_addr & 0xff00)>> 8),
-                     ((serverp->addr.sin_addr.s_addr & 0xff0000)>> 16),
-                     ((serverp->addr.sin_addr.s_addr & 0xff000000)>> 24),
-                     fidp->volume);
-            ptbuf[0] = s;
-            ReportEvent(h, EVENTLOG_WARNING_TYPE, 0, 1009, NULL,
-                         1, 0, ptbuf, NULL);
-            DeregisterEventSource(h);
+        char addr[16];
+        char *format;
+#ifndef DJGPP
+	DWORD msgID;
+#endif
+        switch ( errorCode ) {
+        case VNOVOL:
+#ifndef DJGPP
+	    msgID = MSG_SERVER_REPORTS_VNOVOL;
+#endif
+            format = "Server %s reported volume %d as not attached.";
+            break;
+        case VMOVED:
+#ifndef DJGPP
+	    msgID = MSG_SERVER_REPORTS_VMOVED;
+#endif
+            format = "Server %s reported volume %d as moved.";
+            break;
+        case VOFFLINE:
+#ifndef DJGPP
+	    msgID = MSG_SERVER_REPORTS_VOFFLINE;
+#endif
+            format = "Server %s reported volume %d as offline.";
+            break;
+        case VSALVAGE:
+#ifndef DJGPP
+	    msgID = MSG_SERVER_REPORTS_VSALVAGE;
+#endif
+            format = "Server %s reported volume %d as needs salvage.";
+            break;
+        case VNOSERVICE:
+#ifndef DJGPP
+	    msgID = MSG_SERVER_REPORTS_VNOSERVICE;
+#endif
+            format = "Server %s reported volume %d as not in service.";
+            break;
+        case VIO:
+#ifndef DJGPP
+	    msgID = MSG_SERVER_REPORTS_VIO;
+#endif
+            format = "Server %s reported volume %d as temporarily unaccessible.";
+            break;
         }
 
+        /* Log server being offline for this volume */
+        sprintf(addr, "%d.%d.%d.%d", 
+                 ((serverp->addr.sin_addr.s_addr & 0xff)),
+                 ((serverp->addr.sin_addr.s_addr & 0xff00)>> 8),
+                 ((serverp->addr.sin_addr.s_addr & 0xff0000)>> 16),
+                 ((serverp->addr.sin_addr.s_addr & 0xff000000)>> 24)); 
+
+	osi_Log2(afsd_logp, format, osi_LogSaveString(afsd_logp,addr), fidp->volume);
+#ifndef DJGPP
+	LogEvent(EVENTLOG_WARNING_TYPE, msgID, addr, fidp->volume);
+#endif
+
         /* Mark server offline for this volume */
         if (!serversp) {
             code = cm_GetServerList(fidp, userp, reqp, &serverspp);
@@ -358,6 +406,28 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
         }
         if ( timeLeft > 2 )
             retry = 1;
+    } else if ( errorCode == VNOVNODE ) {
+	if ( fidp ) {
+	    cm_scache_t * scp;
+	    osi_Log4(afsd_logp, "cm_Analyze passed VNOVNODE cell %u vol %u vn %u uniq %u.",
+		      fidp->cell, fidp->volume, fidp->vnode, fidp->unique);
+	    scp = cm_FindSCache(fidp);
+	    if (scp) {
+		cm_scache_t *pscp = cm_FindSCacheParent(scp);
+		cm_CleanFile(scp, userp, reqp);
+  		cm_ReleaseSCache(scp);
+ 		if (pscp) {
+		    if (pscp->cbExpires > 0 && pscp->cbServerp != NULL) {
+ 			lock_ObtainMutex(&pscp->mx);
+ 			cm_DiscardSCache(pscp);
+ 			lock_ReleaseMutex(&pscp->mx);
+ 		    }
+ 		    cm_ReleaseSCache(pscp);
+ 		}
+	    }
+	} else {
+	    osi_Log0(afsd_logp, "cm_Analyze passed VNOVNODE unknown fid.");
+	}
     }
 
     /* RX codes */
@@ -367,26 +437,28 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
          * this is to prevent the SMB session from timing out
          * In addition, we log an event to the event log 
          */
+
+        /* Log server being offline for this volume */
+        sprintf(addr, "%d.%d.%d.%d", 
+                 ((serverp->addr.sin_addr.s_addr & 0xff)),
+                 ((serverp->addr.sin_addr.s_addr & 0xff00)>> 8),
+                 ((serverp->addr.sin_addr.s_addr & 0xff0000)>> 16),
+                 ((serverp->addr.sin_addr.s_addr & 0xff000000)>> 24)); 
+
 #ifndef DJGPP
-        HANDLE h;
-        char *ptbuf[1];
-        char s[100];
-        h = RegisterEventSource(NULL, AFS_DAEMON_EVENT_NAME);
-        sprintf(s, "cm_Analyze: HardDeadTime exceeded.");
-        ptbuf[0] = s;
-        ReportEvent(h, EVENTLOG_WARNING_TYPE, 0, 1009, NULL,
-                     1, 0, ptbuf, NULL);
-        DeregisterEventSource(h);
+	LogEvent(EVENTLOG_WARNING_TYPE, MSG_RX_HARD_DEAD_TIME_EXCEEDED, addr);
 #endif /* !DJGPP */
 	  
         retry = 0;
-        osi_Log0(afsd_logp, "cm_Analyze: hardDeadTime exceeded");
+        osi_Log1(afsd_logp, "cm_Analyze: hardDeadTime exceeded addr[%s]",
+		 osi_LogSaveString(afsd_logp,addr));
     }
     else if (errorCode >= -64 && errorCode < 0) {
         /* mark server as down */
         lock_ObtainMutex(&serverp->mx);
         serverp->flags |= CM_SERVERFLAG_DOWN;
         lock_ReleaseMutex(&serverp->mx);
+	cm_ForceNewConnections(serverp);
         if ( timeLeft > 2 )
             retry = 1;
     }
@@ -437,6 +509,8 @@ cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
             case VRESTRICTED       : s = "VRESTRICTED";        break;
             case VRESTARTING       : s = "VRESTARTING";        break;
             case VREADONLY         : s = "VREADONLY";          break;
+            case EAGAIN            : s = "EAGAIN";             break;
+            case EACCES            : s = "EACCES";             break;
             }
             osi_Log2(afsd_logp, "cm_Analyze: ignoring error code 0x%x (%s)", 
                      errorCode, s);
@@ -463,16 +537,21 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
     cm_serverRef_t *tsrp;
     cm_server_t *tsp;
     long firstError = 0;
-    int someBusy = 0, someOffline = 0, allBusy = 1, allDown = 1;
+    int someBusy = 0, someOffline = 0, allOffline = 1, allBusy = 1, allDown = 1;
     long timeUsed, timeLeft, hardTimeLeft;
 #ifdef DJGPP
     struct timeval now;
 #endif /* DJGPP */        
 
+    if (serversp == NULL) {
+	osi_Log1(afsd_logp, "cm_ConnByMServers returning 0x%x", CM_ERROR_NOSUCHVOLUME);
+	return CM_ERROR_NOSUCHVOLUME;
+    }
+
     *connpp = NULL;
 
 #ifndef DJGPP
-    timeUsed = (GetCurrentTime() - reqp->startTime) / 1000;
+    timeUsed = (GetTickCount() - reqp->startTime) / 1000;
 #else
     gettimeofday(&now, NULL);
     timeUsed = sub_time(now, reqp->startTime) / 1000;
@@ -488,13 +567,15 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
         cm_GetServerNoLock(tsp);
         lock_ReleaseWrite(&cm_serverLock);
         if (!(tsp->flags & CM_SERVERFLAG_DOWN)) {
+	    allDown = 0;
             if (tsrp->status == busy) {
-                allDown = 0;
+		allOffline = 0;
                 someBusy = 1;
             } else if (tsrp->status == offline) {
-                someOffline = 1;
+		allBusy = 0;
+		someOffline = 1;
             } else {
-                allDown = 0;
+		allOffline = 0;
                 allBusy = 0;
                 code = cm_ConnByServer(tsp, usersp, connpp);
                 if (code == 0) {        /* cm_CBS only returns 0 */
@@ -521,15 +602,15 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
         lock_ObtainWrite(&cm_serverLock);
         cm_PutServerNoLock(tsp);
     }   
-
     lock_ReleaseWrite(&cm_serverLock);
+
     if (firstError == 0) {
-        if (serversp == NULL)
-            firstError = CM_ERROR_NOSUCHVOLUME;
-        else if (allDown) 
-            firstError = CM_ERROR_ALLOFFLINE;
+        if (allDown) 
+            firstError = CM_ERROR_ALLDOWN;
         else if (allBusy) 
             firstError = CM_ERROR_ALLBUSY;
+	else if (allOffline || (someBusy && someOffline))
+	    firstError = CM_ERROR_ALLOFFLINE;
         else {
             osi_Log0(afsd_logp, "cm_ConnByMServers returning impossible error TIMEDOUT");
             firstError = CM_ERROR_TIMEDOUT;
@@ -644,7 +725,8 @@ long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, cm_conn_t **connpp)
         tcp->refCount = 1;
         lock_ReleaseMutex(&tcp->mx);
     } else {
-        if ((tcp->ucgen < ucellp->gen) ||
+        if ((tcp->flags & CM_CONN_FLAG_FORCE_NEW) ||
+            (tcp->ucgen < ucellp->gen) ||
             (tcp->cryptlevel != (cryptall ? (ucellp->flags & CM_UCELLFLAG_RXKAD ? rxkad_crypt : rxkad_clear) : rxkad_clear)))
         {
             if (tcp->ucgen < ucellp->gen)
@@ -652,6 +734,7 @@ long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, cm_conn_t **connpp)
             else
                 osi_Log0(afsd_logp, "cm_ConnByServer replace connection due to crypt change");
             lock_ObtainMutex(&tcp->mx);
+	    tcp->flags &= ~CM_CONN_FLAG_FORCE_NEW;
             rx_DestroyConnection(tcp->callp);
             cm_NewRXConnection(tcp, ucellp, serverp);
             lock_ReleaseMutex(&tcp->mx);
@@ -662,7 +745,7 @@ long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, cm_conn_t **connpp)
     lock_ReleaseMutex(&userp->mx);
 
     /* return this pointer to our caller */
-    osi_Log1(afsd_logp, "cm_ConnByServer returning conn 0x%x", (long) tcp);
+    osi_Log1(afsd_logp, "cm_ConnByServer returning conn 0x%p", tcp);
     *connpp = tcp;
 
     return 0;
@@ -697,3 +780,15 @@ cm_GetRxConn(cm_conn_t *connp)
     return rxconn;
 }
 
+void cm_ForceNewConnections(cm_server_t *serverp)
+{
+    cm_conn_t *tcp;
+
+    lock_ObtainWrite(&cm_connLock);
+    for (tcp = serverp->connsp; tcp; tcp=tcp->nextp) {
+	lock_ObtainMutex(&tcp->mx);
+	tcp->flags |= CM_CONN_FLAG_FORCE_NEW;
+	lock_ReleaseMutex(&tcp->mx);
+    }
+    lock_ReleaseWrite(&cm_connLock);
+}
