@@ -25,7 +25,9 @@ typedef struct cm_server {
     struct sockaddr_in addr;		/* by mx */
     int type;				/* by mx */
     struct cm_conn *connsp;		/* locked by cm_connLock */
-    long flags; 			/* by mx */
+    afs_int32 flags;			/* by mx */
+    afs_int32 waitCount;		/* by mx */
+    afs_int32 capabilities;		/* by mx */
     struct cm_cell *cellp;		/* cell containing this server */
     unsigned long refCount;		/* locked by cm_serverLock */
     osi_mutex_t mx;
@@ -38,7 +40,7 @@ typedef struct cm_serverRef {
     struct cm_serverRef *next;      /* locked by cm_serverLock */
     struct cm_server *server;       /* locked by cm_serverLock */
     enum repstate status;           /* locked by cm_serverLock */
-    unsigned long refCount;                   /* locked by cm_serverLock */
+    unsigned long refCount;         /* locked by cm_serverLock */
 } cm_serverRef_t;
 
 /* types */
@@ -48,6 +50,7 @@ typedef struct cm_serverRef {
 /* flags */
 #define CM_SERVERFLAG_DOWN	1	/* server is down */
 #define CM_SERVERFLAG_PREF_SET	2       /* server preference set by user */
+#define CM_SERVERFLAG_PINGING 	4 	/* a ping against this server in progress */
 
 /* flags for procedures */
 #define CM_FLAG_CHECKUPSERVERS		1	/* check working servers */
@@ -68,7 +71,7 @@ extern cm_server_t *cm_NewServer(struct sockaddr_in *addrp, int type,
 
 extern cm_serverRef_t *cm_NewServerRef(struct cm_server *serverp);
 
-extern long cm_ChecksumServerList(cm_serverRef_t *serversp);
+extern LONG_PTR cm_ChecksumServerList(cm_serverRef_t *serversp);
 
 extern void cm_GetServer(cm_server_t *);
 
@@ -100,6 +103,4 @@ extern void cm_FreeServer(cm_server_t* server);
 
 extern void cm_FreeServerList(cm_serverRef_t** list);
 
-extern void cm_ForceNewConnectionsAllServers(void);
-
 #endif /*  __CM_SERVER_H_ENV__ */
