@@ -192,7 +192,6 @@ typedef struct myncb {
 /* one per virtual circuit */
 typedef struct smb_vc {
     struct smb_vc *nextp;		/* not used */
-    afs_uint32 magic;			/* a magic value to detect bad entries */
     unsigned long refCount;		/* the reference count */
     long flags;			        /* the flags, if any; locked by mx */
     osi_mutex_t mx;			/* the mutex */
@@ -214,7 +213,6 @@ typedef struct smb_vc {
     unsigned short session;		/* This is the Session Index associated with the NCBs */
 } smb_vc_t;
 
-#define SMB_VC_MAGIC ('S' | 'C'<<8 | 'A'<<16 | 'C'<<24)
 					/* have we negotiated ... */
 #define SMB_VCFLAG_USEV3	1	/* ... version 3 of the protocol */
 #define SMB_VCFLAG_USECORE	2	/* ... the core protocol */
@@ -224,7 +222,6 @@ typedef struct smb_vc {
 #define SMB_VCFLAG_ALREADYDEAD	0x20	/* do not get tokens from this vc */
 #define SMB_VCFLAG_SESSX_RCVD	0x40	/* we received at least one session setups on this vc */
 #define SMB_VCFLAG_AUTH_IN_PROGRESS 0x80 /* a SMB NT extended authentication is in progress */
-#define SMB_VCFLAG_CLEAN_IN_PROGRESS 0x100
 
 /* one per user session */
 typedef struct smb_user {
@@ -413,7 +410,7 @@ typedef struct smb_dirSearch {
     unsigned long refCount;		/* reference count */
     long cookie;			/* value returned to the caller */
     struct cm_scache *scp;		/* vnode of the dir we're searching */
-    unsigned long lastTime;		/* last time we used this (osi_Time) */
+    time_t lastTime;			/* last time we used this (osi_Time) */
     long flags;			        /* flags (see below);
 					 * locked by smb_globalLock */
     unsigned short attribute;	        /* search attribute
@@ -533,7 +530,9 @@ extern void smb_HoldUIDNoLock(smb_user_t *uidp);
 
 extern void smb_ReleaseUID(smb_user_t *uidp);
 
-extern cm_user_t *smb_GetUser(smb_vc_t *vcp, smb_packet_t *inp);
+extern cm_user_t *smb_GetUserFromVCP(smb_vc_t *vcp, smb_packet_t *inp);
+
+extern cm_user_t *smb_GetUserFromUID(smb_user_t *uidp);
 
 extern long smb_LookupTIDPath(smb_vc_t *vcp, unsigned short tid, char ** tidPathp);
 
@@ -696,10 +695,6 @@ extern char *smb_GetSharename(void);
 
 extern DWORD smb_ServerExceptionFilter(void);
 
-extern void smb_UpdateServerPriority(void);
-extern void smb_SetRequestStartTime(void);
-extern void smb_ResetServerPriority(void);
-
 /* include other include files */
 #include "smb3.h"
 #include "smb_ioctl.h"
