@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.19.2.2 2004/10/18 17:43:53 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.24 2005/10/15 02:32:09 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -42,16 +42,6 @@ extern afs_rwlock_t afs_xcbhash;
 
 /* don't set CDirty in here because RPC is called synchronously */
 int afs_symlink
-#ifdef	AFS_OSF_ENV
-  (ndp, attrs, atargetName)
-     struct nameidata *ndp;
-     struct vattr *attrs;
-     register char *atargetName;
-{
-    register struct vcache *adp = VTOAFS(ndp->ni_dvp);
-    char *aname = ndp->ni_dent.d_name;
-    struct ucred *acred = ndp->ni_cred;
-#else				/* AFS_OSF_ENV */
   (OSI_VC_ARG(adp), aname, attrs, atargetName, acred)
      OSI_VC_DECL(adp);
      char *atargetName;
@@ -59,7 +49,6 @@ int afs_symlink
      struct vattr *attrs;
      struct AFS_UCRED *acred;
 {
-#endif
     afs_uint32 now = 0;
     struct vrequest treq;
     afs_int32 code;
@@ -184,10 +173,10 @@ int afs_symlink
     /* otherwise, we should see if we can make the change to the dir locally */
     if (afs_LocalHero(adp, tdc, &OutDirStatus, 1)) {
 	/* we can do it locally */
-	code = afs_dir_Create(&tdc->f, aname, &newFid.Fid);
+	code = afs_dir_Create(tdc, aname, &newFid.Fid);
 	if (code) {
 	    ZapDCE(tdc);	/* surprise error -- use invalid value */
-	    DZap(&tdc->f);
+	    DZap(tdc);
 	}
     }
     if (tdc) {
@@ -202,6 +191,12 @@ int afs_symlink
      * no one can get a pointer to the new cache entry until we release 
      * the xvcache lock. */
     tvc = afs_NewVCache(&newFid, hostp);
+    if (!tvc)
+    {
+	code = -2;
+	ReleaseWriteLock(&afs_xvcache);
+	goto done;
+    }
     ObtainWriteLock(&tvc->lock, 157);
     ObtainWriteLock(&afs_xcbhash, 500);
     tvc->states |= CStatd;	/* have valid info */
@@ -236,9 +231,6 @@ int afs_symlink
 	afs_PutVolume(volp, READ_LOCK);
     code = afs_CheckCode(code, &treq, 31);
   done2:
-#ifdef  AFS_OSF_ENV
-    AFS_RELE(ndp->ni_dvp);
-#endif /* AFS_OSF_ENV */
     return code;
 }
 
