@@ -21,7 +21,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_write.c,v 1.36.2.6 2005/10/03 02:55:33 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_write.c,v 1.48 2005/10/13 15:12:08 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -105,8 +105,13 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
     volatile
 #endif
     afs_int32 error;
+#ifdef AFS_DARWIN80_ENV
+    uio_t tuiop;
+#else
     struct uio tuio;
+    struct uio *tuiop = &tuio;
     struct iovec *tvec;		/* again, should have define */
+#endif
     register afs_int32 code;
     struct vrequest treq;
 
@@ -118,8 +123,8 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
     if ((code = afs_InitReq(&treq, acred)))
 	return code;
     /* otherwise we read */
-    totalLength = auio->afsio_resid;
-    filePos = auio->afsio_offset;
+    totalLength = AFS_UIO_RESID(auio);
+    filePos = AFS_UIO_OFFSET(auio);
     error = 0;
     transferLength = 0;
     afs_Trace4(afs_iclSetp, CM_TRACE_WRITE, ICL_TYPE_POINTER, avc,
@@ -141,8 +146,8 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 	 */
 	osi_Assert(filePos <= avc->m.Length);
 	diff = avc->m.Length - filePos;
-	auio->afsio_resid = MIN(totalLength, diff);
-	totalLength = auio->afsio_resid;
+	AFS_UIO_SETRESID(auio, MIN(totalLength, diff));
+	totalLength = AFS_UIO_RESID(auio);
     }
 #else
     if (aio & IO_APPEND) {
@@ -150,7 +155,8 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 #if	defined(AFS_SUN56_ENV)
 	auio->uio_loffset = 0;
 #endif
-	filePos = auio->afsio_offset = avc->m.Length;
+	filePos = avc->m.Length;
+	AFS_UIO_SETOFFSET(auio, filePos);
     }
 #endif
     /*
@@ -184,7 +190,9 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
     afs_FakeOpen(avc);
 #endif
     avc->states |= CDirty;
+#ifndef AFS_DARWIN80_ENV
     tvec = (struct iovec *)osi_AllocSmallSpace(sizeof(struct iovec));
+#endif
     while (totalLength > 0) {
 	/* 
 	 *  The following line is necessary because afs_GetDCache with
@@ -198,7 +206,7 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 	    if (tdc)
 		ObtainWriteLock(&tdc->lock, 653);
 	} else if (afs_blocksUsed >
-		   (CM_WAITFORDRAINPCT * afs_cacheBlocks) / 100) {
+		   PERCENT(CM_WAITFORDRAINPCT, afs_cacheBlocks)) {
 	    tdc = afs_FindDCache(avc, filePos);
 	    if (tdc) {
 		ObtainWriteLock(&tdc->lock, 654);
@@ -212,10 +220,10 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 	    if (!tdc) {
 		afs_MaybeWakeupTruncateDaemon();
 		while (afs_blocksUsed >
-		       (CM_WAITFORDRAINPCT * afs_cacheBlocks) / 100) {
+		       PERCENT(CM_WAITFORDRAINPCT, afs_cacheBlocks)) {
 		    ReleaseWriteLock(&avc->lock);
 		    if (afs_blocksUsed - afs_blocksDiscarded >
-			(CM_WAITFORDRAINPCT * afs_cacheBlocks) / 100) {
+			PERCENT(CM_WAITFORDRAINPCT, afs_cacheBlocks)) {
 			afs_WaitForCacheDrain = 1;
 			afs_osi_Sleep(&afs_WaitForCacheDrain);
 		    }
@@ -254,13 +262,19 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 	     * as will fit */
 	    len = max - offset;
 	}
+
+#ifdef  AFS_DARWIN80_ENV
+	trimlen = len;
+	tuiop = afsio_darwin_partialcopy(auio, trimlen);
+#else
 	/* mung uio structure to be right for this transfer */
 	afsio_copy(auio, &tuio, tvec);
 	trimlen = len;
 	afsio_trim(&tuio, trimlen);
-	tuio.afsio_offset = offset;
+#endif
+	AFS_UIO_SETOFFSET(tuiop, offset);
 
-	code = afs_MemWriteUIO(tdc->f.inode, &tuio);
+	code = afs_MemWriteUIO(tdc->f.inode, tuiop);
 	if (code) {
 	    void *mep;		/* XXX in prototype world is struct memCacheEntry * */
 	    error = code;
@@ -275,7 +289,7 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 	    break;
 	}
 	/* otherwise we've written some, fixup length, etc and continue with next seg */
-	len = len - tuio.afsio_resid;	/* compute amount really transferred */
+	len = len - AFS_UIO_RESID(tuiop);	/* compute amount really transferred */
 	tlen = len;
 	afsio_skip(auio, tlen);	/* advance auio over data written */
 	/* compute new file size */
@@ -323,7 +337,11 @@ afs_MemWrite(register struct vcache *avc, struct uio *auio, int aio,
 	avc->vc_error = error;
     if (!noLock)
 	ReleaseWriteLock(&avc->lock);
+#ifdef AFS_DARWIN80_ENV
+    uio_free(tuiop);
+#else
     osi_FreeSmallSpace(tvec);
+#endif
     error = afs_CheckCode(error, &treq, 6);
     return error;
 }
@@ -347,8 +365,13 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
     volatile
 #endif
     afs_int32 error;
+#ifdef AFS_DARWIN80_ENV
+    uio_t tuiop;
+#else
     struct uio tuio;
+    struct uio *tuiop = &tuio;
     struct iovec *tvec;		/* again, should have define */
+#endif
     struct osi_file *tfile;
     register afs_int32 code;
     struct vrequest treq;
@@ -361,8 +384,8 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
     if ((code = afs_InitReq(&treq, acred)))
 	return code;
     /* otherwise we read */
-    totalLength = auio->afsio_resid;
-    filePos = auio->afsio_offset;
+    totalLength = AFS_UIO_RESID(auio);
+    filePos = AFS_UIO_OFFSET(auio);
     error = 0;
     transferLength = 0;
     afs_Trace4(afs_iclSetp, CM_TRACE_WRITE, ICL_TYPE_POINTER, avc,
@@ -384,8 +407,8 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	 */
 	osi_Assert(filePos <= avc->m.Length);
 	diff = avc->m.Length - filePos;
-	auio->afsio_resid = MIN(totalLength, diff);
-	totalLength = auio->afsio_resid;
+	AFS_UIO_SETRESID(auio, MIN(totalLength, diff));
+	totalLength = AFS_UIO_RESID(auio);
     }
 #else
     if (aio & IO_APPEND) {
@@ -393,7 +416,8 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 #if     defined(AFS_SUN56_ENV)
 	auio->uio_loffset = 0;
 #endif
-	filePos = auio->afsio_offset = avc->m.Length;
+	filePos = avc->m.Length;
+	AFS_UIO_SETOFFSET(auio, avc->m.Length);
     }
 #endif
     /*
@@ -427,7 +451,9 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
     afs_FakeOpen(avc);
 #endif
     avc->states |= CDirty;
+#ifndef AFS_DARWIN80_ENV
     tvec = (struct iovec *)osi_AllocSmallSpace(sizeof(struct iovec));
+#endif
     while (totalLength > 0) {
 	/* 
 	 *  The following line is necessary because afs_GetDCache with
@@ -442,7 +468,7 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	    if (tdc)
 		ObtainWriteLock(&tdc->lock, 657);
 	} else if (afs_blocksUsed >
-		   (CM_WAITFORDRAINPCT * afs_cacheBlocks) / 100) {
+		   PERCENT(CM_WAITFORDRAINPCT, afs_cacheBlocks)) {
 	    tdc = afs_FindDCache(avc, filePos);
 	    if (tdc) {
 		ObtainWriteLock(&tdc->lock, 658);
@@ -456,10 +482,10 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	    if (!tdc) {
 		afs_MaybeWakeupTruncateDaemon();
 		while (afs_blocksUsed >
-		       (CM_WAITFORDRAINPCT * afs_cacheBlocks) / 100) {
+		       PERCENT(CM_WAITFORDRAINPCT, afs_cacheBlocks)) {
 		    ReleaseWriteLock(&avc->lock);
 		    if (afs_blocksUsed - afs_blocksDiscarded >
-			(CM_WAITFORDRAINPCT * afs_cacheBlocks) / 100) {
+			PERCENT(CM_WAITFORDRAINPCT, afs_cacheBlocks)) {
 			afs_WaitForCacheDrain = 1;
 			afs_osi_Sleep(&afs_WaitForCacheDrain);
 		    }
@@ -499,11 +525,18 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	     * as will fit */
 	    len = max - offset;
 	}
+
+#ifdef  AFS_DARWIN80_ENV
+	trimlen = len;
+	tuiop = afsio_darwin_partialcopy(auio, trimlen);
+#else
 	/* mung uio structure to be right for this transfer */
 	afsio_copy(auio, &tuio, tvec);
 	trimlen = len;
 	afsio_trim(&tuio, trimlen);
-	tuio.afsio_offset = offset;
+#endif
+	AFS_UIO_SETOFFSET(tuiop, offset);
+
 #if defined(AFS_AIX41_ENV)
 	AFS_GUNLOCK();
 	code =
@@ -563,6 +596,10 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	AFS_GUNLOCK();
 	code = osi_rdwr(tfile, &tuio, UIO_WRITE);
 	AFS_GLOCK();
+#elif defined(AFS_DARWIN80_ENV)
+	AFS_GUNLOCK();
+	code = VNOP_WRITE(tfile->vnode, tuiop, 0, afs_osi_ctxtp);
+	AFS_GLOCK();
 #elif defined(AFS_DARWIN_ENV)
 	AFS_GUNLOCK();
 	VOP_LOCK(tfile->vnode, LK_EXCLUSIVE, current_proc());
@@ -600,7 +637,7 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	    break;
 	}
 	/* otherwise we've written some, fixup length, etc and continue with next seg */
-	len = len - tuio.afsio_resid;	/* compute amount really transferred */
+	len = len - AFS_UIO_RESID(tuiop);	/* compute amount really transferred */
 	tlen = len;
 	afsio_skip(auio, tlen);	/* advance auio over data written */
 	/* compute new file size */
@@ -651,7 +688,11 @@ afs_UFSWrite(register struct vcache *avc, struct uio *auio, int aio,
 	avc->vc_error = error;
     if (!noLock)
 	ReleaseWriteLock(&avc->lock);
+#ifdef AFS_DARWIN80_ENV
+    uio_free(tuiop);
+#else
     osi_FreeSmallSpace(tvec);
+#endif
 #ifndef	AFS_VM_RDWR_ENV
     /*
      * If write is implemented via VM, afs_fsync() is called from the high-level
