@@ -86,8 +86,6 @@ extern int afs_shuttingdown;
 #define	AFS_NRXPACKETS	80
 #define	AFS_RXDEADTIME	50
 #define AFS_HARDDEADTIME	120
-#define AFS_BLKBITS	12
-#define AFS_BLKSIZE	(1 << AFS_BLKBITS)
 
 extern afs_int32 afs_rx_deadtime;
 extern afs_int32 afs_rx_harddead;
@@ -268,9 +266,6 @@ enum { AFS_GCPAGS_NOTCOMPILED = 0, AFS_GCPAGS_OK =
 extern afs_int32 afs_gcpags;
 extern afs_int32 afs_gcpags_procsize;
 extern afs_int32 afs_bkvolpref;
-extern char afs_cachebasedir[1024];
-extern afs_int32 afs_numcachefiles;
-extern afs_int32 afs_numfilesperdir;
 
 struct unixuser {
     struct unixuser *next;	/* next hash pointer */
@@ -838,6 +833,9 @@ struct cm_initparams {
 
 #define	NULLIDX	    (-1)	/* null index definition */
 /* struct dcache states bits */
+#define DRO         1
+#define DBackup     2
+#define DRW         4
 #define	DWriting    8		/* file being written (used for cache validation) */
 
 /* dcache data flags */
@@ -914,9 +912,6 @@ struct afs_fheader {
 #endif
 #endif
 
-
-#ifdef KERNEL
-/* it does not compile outside kernel */
 struct buffer {
   afs_int32 fid;              /* is adc->index, the cache file number */
   afs_inode_t inode;          /* is adc->f.inode, the inode number of the cac\
@@ -944,7 +939,6 @@ struct fcache {
     afs_int32 chunkBytes;	/* Num bytes in this chunk */
     char states;		/* Has this chunk been modified? */
 };
-#endif
 
 /* magic numbers to specify the cache type */
 
@@ -966,7 +960,7 @@ struct dcache {
     char dflags;		/* Data flags */
     char mflags;		/* Meta flags */
     struct fcache f;		/* disk image */
-
+    afs_int32 bucket;           /* which bucket these dcache entries are in */
     /*
      * Locking rules:
      *
@@ -1222,9 +1216,4 @@ struct afs_fakestat_state {
 
 extern int afs_fakestat_enable;
 
-/* First 32 bits of capabilities */
-#define CAPABILITY_ERRORTRANS (1<<0)
-
-#define CAPABILITY_BITS 1
-
 #endif /* _AFS_H_ */
