@@ -17,7 +17,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_callback.c,v 1.27.2.2 2005/05/30 04:05:40 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_callback.c,v 1.37 2006/01/24 17:32:43 shadow Exp $");
 
 #include "afs/sysincludes.h"	/*Standard vendor system headers */
 #include "afsincludes.h"	/*AFS-based standard headers */
@@ -59,7 +59,9 @@ static struct ltable {
     "afs_xosi", (char *)&afs_xosi},
 #endif
     {
-    "afs_xsrvAddr", (char *)&afs_xsrvAddr}
+      "afs_xsrvAddr", (char *)&afs_xsrvAddr},
+    {
+    "afs_xvreclaim", (char *)&afs_xvreclaim}
 };
 unsigned long lastCallBack_vnode;
 unsigned int lastCallBack_dv;
@@ -151,7 +153,15 @@ SRXAFSCB_GetCE(struct rx_call *a_call, afs_int32 a_index,
     a_result->DataVersion = hgetlo(tvc->m.DataVersion);
     a_result->callback = afs_data_pointer_to_int32(tvc->callback);	/* XXXX Now a pointer; change it XXXX */
     a_result->cbExpires = tvc->cbExpires;
+    if (tvc->states & CVInit) {
+        a_result->refCount = 1;
+    } else {
+#ifdef AFS_DARWIN80_ENV
+    a_result->refCount = vnode_isinuse(AFSTOV(tvc),0)?1:0; /* XXX fix */
+#else
     a_result->refCount = VREFCOUNT(tvc);
+#endif
+    }
     a_result->opens = tvc->opens;
     a_result->writers = tvc->execsOrWriters;
     a_result->mvstat = tvc->mvstat;
@@ -230,7 +240,15 @@ SRXAFSCB_GetCE64(struct rx_call *a_call, afs_int32 a_index,
     a_result->DataVersion = hgetlo(tvc->m.DataVersion);
     a_result->callback = afs_data_pointer_to_int32(tvc->callback);	/* XXXX Now a pointer; change it XXXX */
     a_result->cbExpires = tvc->cbExpires;
+    if (tvc->states & CVInit) {
+        a_result->refCount = 1;
+    } else {
+#ifdef AFS_DARWIN80_ENV
+    a_result->refCount = vnode_isinuse(AFSTOV(tvc),0)?1:0; /* XXX fix */
+#else
     a_result->refCount = VREFCOUNT(tvc);
+#endif
+    }
     a_result->opens = tvc->opens;
     a_result->writers = tvc->execsOrWriters;
     a_result->mvstat = tvc->mvstat;
@@ -384,12 +402,15 @@ ClearCallBack(register struct rx_connection *a_conn,
      */
     if (a_fid->Volume != 0) {
 	if (a_fid->Vnode == 0) {
+		struct afs_q *tq, *uq;
 	    /*
 	     * Clear callback for the whole volume.  Zip through the
 	     * hash chain, nullifying entries whose volume ID matches.
 	     */
 		i = VCHashV(&localFid);
-		for (tvc = afs_vhashTV[i]; tvc; tvc = tvc->vhnext) {
+		for (tq = afs_vhashTV[i].prev; tq != &afs_vhashTV[i]; tq = uq) {
+		    uq = QPrev(tq);
+		    tvc = QTOVH(tq);      
 		    if (tvc->fid.Fid.Volume == a_fid->Volume) {
 			tvc->callback = NULL;
 			if (!localFid.Cell)
@@ -404,7 +425,8 @@ ClearCallBack(register struct rx_connection *a_conn,
 			else
 			    afs_evenCBs++;
 			ReleaseWriteLock(&afs_xcbhash);
-			if (tvc->fid.Fid.Vnode & 1 || (vType(tvc) == VDIR))
+			if (!(tvc->states & CVInit) &&
+			    (tvc->fid.Fid.Vnode & 1 || (vType(tvc) == VDIR)))
 			    osi_dnlc_purgedp(tvc);
 			afs_Trace3(afs_iclSetp, CM_TRACE_CALLBACK,
 				   ICL_TYPE_POINTER, tvc, ICL_TYPE_INT32,
@@ -448,7 +470,8 @@ ClearCallBack(register struct rx_connection *a_conn,
 		    afs_DequeueCallback(tvc);
 		    tvc->states &= ~(CStatd | CUnique | CBulkFetching);
 		    ReleaseWriteLock(&afs_xcbhash);
-		    if (a_fid->Vnode & 1 || (vType(tvc) == VDIR))
+		    if (!(tvc->states & CVInit) &&
+		        (tvc->fid.Fid.Vnode & 1 || (vType(tvc) == VDIR)))
 			osi_dnlc_purgedp(tvc);
 		    afs_Trace3(afs_iclSetp, CM_TRACE_CALLBACK,
 			       ICL_TYPE_POINTER, tvc, ICL_TYPE_INT32,
@@ -1513,9 +1536,147 @@ SRXAFSCB_TellMeAboutYourself(struct rx_call *a_call,
 
     dataBytes = 1 * sizeof(afs_int32);
     dataBuffP = (afs_int32 *) afs_osi_Alloc(dataBytes);
-    dataBuffP[0] = CAPABILITY_ERRORTRANS;
+    dataBuffP[0] = CLIENT_CAPABILITY_ERRORTRANS;
     capabilities->Capabilities_len = dataBytes / sizeof(afs_int32);
     capabilities->Capabilities_val = dataBuffP;
 
     return code;
 }
+
+
+#ifdef AFS_LINUX24_ENV
+extern struct vcache *afs_globalVp;
+
+int recurse_dcache_parent(parent, a_index, addr, inode, flags, time, fileName)
+     struct dentry * parent;
+    afs_int32 a_index;
+    afs_int32 *addr;
+    afs_int32 *inode;
+    afs_int32 *flags;
+    afs_int32 *time;
+    char ** fileName;
+{
+	struct dentry *this_parent = parent;
+	struct list_head *next;
+	int found = 0;
+	struct dentry *dentry;
+
+repeat:
+	next = this_parent->d_subdirs.next;
+resume:
+	while (next != &this_parent->d_subdirs) {
+		struct list_head *tmp = next;
+		dentry = list_entry(tmp, struct dentry, d_child);
+		if (a_index == 0)
+		  goto searchdone3;
+		a_index--;
+		next = tmp->next;
+		/*
+		 * Descend a level if the d_subdirs list is non-empty.
+		 */
+		if (!list_empty(&dentry->d_subdirs)) {
+			this_parent = dentry;
+			goto repeat;
+		}
+	}
+	/*
+	 * All done at this level ... ascend and resume the search.
+	 */
+	if (this_parent != parent) {
+		next = this_parent->d_child.next; 
+		this_parent = this_parent->d_parent;
+		goto resume;
+	}
+	goto ret;
+
+ searchdone3:
+    if (d_unhashed(dentry))
+      *flags = 1;
+    else 
+      *flags = 0;
+
+    *fileName = afs_strdup(dentry->d_name.name?dentry->d_name.name:"");
+    *inode = ITOAFS(dentry->d_inode);
+    *addr = atomic_read(&(dentry)->d_count);
+    *time = dentry->d_time;
+
+    return 0;
+ ret:
+    return 1;
+}
+#endif
+
+int SRXAFSCB_GetDE(a_call, a_index, addr, inode, flags, time, fileName)
+    struct rx_call *a_call;
+    afs_int32 a_index;
+    afs_int32 *addr;
+    afs_int32 *inode;
+    afs_int32 *flags;
+    afs_int32 *time;
+    char ** fileName;
+{ /*SRXAFSCB_GetDE*/
+    int code = 0;				/*Return code*/
+#ifdef AFS_LINUX24_ENV
+    register int i;			/*Loop variable*/
+    register struct vcache *tvc = afs_globalVp;
+    struct dentry *dentry;
+    struct list_head *cur, *head = &(AFSTOI(tvc))->i_dentry;
+
+#ifdef RX_ENABLE_LOCKS
+    AFS_GLOCK();
+#endif /* RX_ENABLE_LOCKS */
+
+#if defined(AFS_LINUX24_ENV)
+    spin_lock(&dcache_lock);
+#endif
+
+    cur = head;
+    while ((cur = cur->next) != head) {
+      dentry = list_entry(cur, struct dentry, d_alias);
+      
+      dget_locked(dentry);
+      
+#if defined(AFS_LINUX24_ENV)
+      spin_unlock(&dcache_lock);
+#endif
+      if (a_index == 0)
+	goto searchdone2;
+      a_index--;
+
+      if (recurse_dcache_parent(dentry, a_index, addr, inode, flags, time, fileName) == 0) {
+	dput(dentry);
+	code = 0;
+	goto fcnDone;
+      }
+      dput(dentry);
+    }                   
+ searchdone2:
+    if (cur == head) {
+	/*Past EOF*/
+	code = 1;
+	*fileName = afs_strdup("");
+	goto fcnDone;
+    }
+
+    if (d_unhashed(dentry))
+      *flags = 1;
+    else 
+      *flags = 0;
+
+    *fileName = afs_strdup(dentry->d_name.name?dentry->d_name.name:"");
+    *inode = ITOAFS(dentry->d_inode);
+    *addr = atomic_read(&(dentry)->d_count);
+    *time = dentry->d_time;
+
+    dput(dentry);
+    code = 0;
+
+fcnDone:
+
+#ifdef RX_ENABLE_LOCKS
+    AFS_GUNLOCK();
+#endif /* RX_ENABLE_LOCKS */
+#endif
+    return(code);
+
+} /*SRXAFSCB_GetDE*/
