@@ -17,7 +17,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/lwp/lwp.c,v 1.27.2.1 2004/08/25 07:03:40 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/lwp/lwp.c,v 1.33 2005/06/18 23:20:45 shadow Exp $");
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -145,9 +145,7 @@ int lwp_nextindex;
 int lwp_MinStackSize = 0;
 
 static int
-lwp_remove(p, q)
-     register PROCESS p;
-     register struct QUEUE *q;
+lwp_remove(register PROCESS p, register struct QUEUE *q)
 {
     /* Special test for only element on queue */
     if (q->count == 1)
@@ -166,9 +164,7 @@ lwp_remove(p, q)
 }
 
 static int
-insert(p, q)
-     register PROCESS p;
-     register struct QUEUE *q;
+insert(register PROCESS p, register struct QUEUE *q)
 {
     if (q->head == NULL) {	/* Queue is empty */
 	q->head = p;
@@ -184,9 +180,7 @@ insert(p, q)
 }
 
 static int
-move(p, from, to)
-     PROCESS p;
-     struct QUEUE *from, *to;
+move(PROCESS p, struct QUEUE *from, struct QUEUE *to)
 {
 
     lwp_remove(p, from);
@@ -248,8 +242,7 @@ LWP_QWait(void)
 }
 
 int
-LWP_QSignal(pid)
-     register PROCESS pid;
+LWP_QSignal(register PROCESS pid)
 {
     if (pid->status == QWAITING) {
 	pid->status = READY;
@@ -279,6 +272,7 @@ LWP_CreateProcess(int (*ep) (), int stacksize, int priority, void *parm,
 #else
     char *stackptr;
 #endif
+    char *stackmemory;
 
 #if defined(AFS_LWP_MINSTACKSIZE)
     /*
@@ -346,20 +340,21 @@ LWP_CreateProcess(int (*ep) (), int stacksize, int priority, void *parm,
 	    stackptr = reserveFromStack(lwp_MaxStackSize);
 	}
 	stackptr -= stacksize;
+	stackmemory = stackptr;
 #else
-	if ((stackptr = (char *)malloc(stacksize + 7)) == NULL) {
+	if ((stackmemory = (char *)malloc(stacksize + 7)) == NULL) {
 	    Set_LWP_RC();
 	    return LWP_ENOMEM;
 	}
 	/* Round stack pointer to byte boundary */
-	stackptr = (char *)(8 * (((long)stackptr + 7) / 8));
+	stackptr = (char *)(8 * (((long)stackmemory + 7) / 8));
 #endif
 	if (priority < 0 || priority >= MAX_PRIORITIES) {
 	    Set_LWP_RC();
 	    return LWP_EBADPRI;
 	}
 	Initialize_Stack(stackptr, stacksize);
-	Initialize_PCB(temp, priority, stackptr, stacksize, ep, parm, name);
+	Initialize_PCB(temp, priority, stackmemory, stacksize, ep, parm, name);
 	insert(temp, &runnable[priority]);
 	temp2 = lwp_cpptr;
 	if (PRE_Block != 0)
@@ -835,7 +830,6 @@ Dump_One_Process(PROCESS pid)
 	       pid->stacksize, pid->stack);
 	printf("***LWP: HWM stack usage: ");
 	printf("%d\n", Stack_Used(pid->stack, pid->stacksize));
-	free(pid->stack);
     }
     printf("***LWP: Current Stack Pointer: 0x%x\n", pid->context.topstack);
     if (pid->eventcnt > 0) {
@@ -999,7 +993,9 @@ Free_PCB(PROCESS pid)
 	Debug(0,
 	      ("HWM stack usage: %d, [PCB at 0x%x]",
 	       Stack_Used(pid->stack, pid->stacksize), pid));
+#ifndef AFS_AIX32_ENV
 	free(pid->stack);
+#endif
     }
     if (pid->eventlist != NULL)
 	free(pid->eventlist);
