@@ -51,7 +51,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/ptprocs.c,v 1.21.2.10 2009/03/19 03:45:02 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/ptprocs.c,v 1.28 2005/12/08 01:13:37 jaltman Exp $");
 
 #include <afs/stds.h>
 #include <ctype.h>
@@ -69,7 +69,13 @@ RCSID
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include "ptserver.h"
 #include "pterror.h"
 #include "ptprototypes.h"
@@ -98,6 +104,7 @@ afs_int32 listElements(), listOwned(), isAMemberOf(), idToName();
 afs_int32 listSuperGroups();
 #endif
 
+static stolower();
 extern int IDCmp();
 
 extern int prp_group_default;
@@ -174,7 +181,7 @@ WhoIsThis(acall, at, aid)
 	    goto done;
 #endif
 	if (tcell[0])
-	    foreign = afs_is_foreign_ticket_name(name,inst,tcell,pr_realmName);
+	    foreign = afs_is_foreign_ticket_name(tcell,name,inst,pr_realmName);
 
 	strncpy(vname, name, sizeof(vname));
 	if (ilen = strlen(inst)) {
@@ -622,24 +629,7 @@ nameToID(call, aname, aid)
 	ABORT_WITH(tt, code);
 
     for (i = 0; i < aname->namelist_len; i++) {
-	char vname[256];
-	char *nameinst, *cell;
-
-	strncpy(vname, aname->namelist_val[i], sizeof(vname));
-	vname[sizeof(vname)-1] ='\0';
-
-	nameinst = vname;
-	cell = strchr(vname, '@');
-	if (cell) {
-	    *cell = '\0';
-	    cell++;
-	}
-
-	if (cell && afs_is_foreign_ticket_name(nameinst,NULL,cell,pr_realmName))
-	    code = NameToID(tt, aname->namelist_val[i], &aid->idlist_val[i]);
-	else 
-	    code = NameToID(tt, nameinst, &aid->idlist_val[i]);
-
+	code = NameToID(tt, aname->namelist_val[i], &aid->idlist_val[i]);
 	if (code != PRSUCCESS)
 	    aid->idlist_val[i] = ANONYMOUSID;
         osi_audit(PTS_NmToIdEvent, code, AUD_STR,
@@ -2227,6 +2217,19 @@ isAMemberOf(call, uid, gid, flag, cid)
     return code;
 }
 
+
+static
+stolower(s)
+     register char *s;
+{
+    register int tc;
+    while ((tc = *s)) {
+	if (isupper(tc))
+	    *s = tolower(tc);
+	s++;
+    }
+}
+
 #if IP_WILDCARDS
 afs_int32
 addWildCards(tt, alist, host)
@@ -2321,7 +2324,7 @@ WhoIsThisWithName(acall, at, aid, aname)
 	    strcat(vname, inst);
 	}
 	if ((clen = strlen(tcell))) {
-	    int foreign = afs_is_foreign_ticket_name(name,inst,tcell,pr_realmName);
+	    int foreign = afs_is_foreign_ticket_name(tcell,name,inst,pr_realmName);
 
 	    if (foreign) {
 		if (strlen(vname) + 1 + clen >= sizeof(vname))
