@@ -7,11 +7,23 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+/*
+ *                      (3) add new pts commands:
+ *
+ *                          Interactive - allow the pts command
+ *                                        to be run interactively.
+ *                          Quit        - quit interactive mode.
+ *                          Source      - allow input to come from a file(s).
+ *                          Sleep       - pause for a specified number
+ *                                        of seconds.
+ *
+ */
+
 #include <afsconfig.h>
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.13.2.7 2008/03/18 15:59:07 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.14 2004/10/13 14:23:25 jaltman Exp $");
 
 #include <stdio.h>
 #include <string.h>
@@ -34,13 +46,23 @@ RCSID
 #include "ptclient.h"
 #include "pterror.h"
 #include <afs/afsutil.h>
-#include <afs/com_err.h>
 
 #undef FOREIGN
 
 char *whoami;
 int force = 0;
 
+#if defined(SUPERGROUPS)
+
+/*
+ *  Add new pts commands:
+ *
+ *      Interactive - allow the pts command to be run interactively.
+ *      Quit        - quit interactive mode.
+ *      Source      - allow input to come from a file(s).
+ *      Sleep       - pause for a specified number of seconds.
+ */
+
 static int finished;
 static FILE *source;
 extern struct ubik_client *pruclient;
@@ -50,29 +72,22 @@ struct sourcestack {
     FILE *s_file;
 } *shead;
 
-struct authstate {
-    int sec;
-    const char *confdir;
-    char cell[MAXCELLCHARS];
-};
-
 int
-pts_Interactive(register struct cmd_syndesc *as)
+Interactive(register struct cmd_syndesc *as)
 {
-    source = stdin;
     finished = 0;
     return 0;
 }
 
 int
-pts_Quit(register struct cmd_syndesc *as)
+Quit(register struct cmd_syndesc *as)
 {
     finished = 1;
     return 0;
 }
 
 int
-pts_Source(register struct cmd_syndesc *as)
+Source(register struct cmd_syndesc *as)
 {
     FILE *fd;
     struct sourcestack *sp;
@@ -100,7 +115,7 @@ pts_Source(register struct cmd_syndesc *as)
 }
 
 int
-pts_Sleep(register struct cmd_syndesc *as)
+Sleep(register struct cmd_syndesc *as)
 {
     int delay;
     if (!as->parms[0].items) {
@@ -109,7 +124,6 @@ pts_Sleep(register struct cmd_syndesc *as)
     }
     delay = atoi(as->parms[0].items->data);
     IOMGR_Sleep(delay);
-    return 0;
 }
 
 int
@@ -126,6 +140,8 @@ popsource()
     return 1;
 }
 
+#endif /* SUPERGROUPS */
+
 int
 osi_audit()
 {
@@ -137,79 +153,41 @@ osi_audit()
 }
 
 int
-GetGlobals(struct cmd_syndesc *as, void *arock)
+GetGlobals(register struct cmd_syndesc *as)
 {
-    struct authstate *state = (struct authstate *) arock;
-    afs_int32 code;
-    char *cell = NULL;
-    afs_int32 sec;
-    int changed = 0;
-    const char* confdir;
+    register afs_int32 code;
+    char *cell;
+    afs_int32 sec = 1;
 
     whoami = as->a0name;
 
     if (!strcmp(as->name, "help"))
 	return 0;
-
-    if (*state->cell) {
-	cell = state->cell;
-    }
-    sec = state->sec;
-
-    if (state->confdir == NULL) {
-	changed = 1;
-    }
-
-    if (as->parms[16].items) {
-	changed = 1;
+    if (as->parms[16].items)
 	cell = as->parms[16].items->data;
-    }
-    if (as->parms[17].items) { /* -noauth */
-	changed = 1;
+    else
+	cell = 0;
+    if (as->parms[17].items)
 	sec = 0;
-    }
-    if (as->parms[20].items) { /* -localauth */
-	changed = 1;
-	sec = 2;
-    }
-    if (as->parms[21].items) { /* -auth */
-	changed = 1;
-	sec = 1;
-    }
-    if (as->parms[18].items || as->parms[20].items) {	/* -test, -localauth */
-	changed = 1;
-	confdir = AFSDIR_SERVER_ETC_DIRPATH;
+
+    if (as->parms[18].items) {	/* testing? */
+	code = pr_Initialize(sec, AFSDIR_SERVER_ETC_DIRPATH, cell);
     } else {
-	if (sec == 2)
-	    confdir = AFSDIR_SERVER_ETC_DIRPATH;
-	else 
-	    confdir = AFSDIR_CLIENT_ETC_DIRPATH;
-    }
-    if (changed) {
-	CleanUp(as, arock);
-	code = pr_Initialize(sec, confdir, cell);
-    } else {
-	code = 0;
+	code = pr_Initialize(sec, AFSDIR_CLIENT_ETC_DIRPATH, cell);
     }
     if (code) {
-	afs_com_err(whoami, code, "while initializing");
+	com_err(whoami, code, "while initializing");
 	return code;
     }
-    state->sec = sec;
-    state->confdir = confdir;
-    if (cell && cell != state->cell)
-	strncpy(state->cell, cell, MAXCELLCHARS-1);
-
-    force = 0;
     if (as->parms[19].items)
 	force = 1;
-
     return code;
 }
 
 int
-CleanUp(register struct cmd_syndesc *as, void *arock)
+CleanUp(register struct cmd_syndesc *as)
 {
+#if defined(SUPERGROUPS)
     if (as && !strcmp(as->name, "help"))
 	return 0;
     if (pruclient) {
@@ -217,6 +195,14 @@ CleanUp(register struct cmd_syndesc *as, void *arock)
 	pr_End();
 	rx_Finalize();
     }
+#else
+    if (!strcmp(as->name, "help"))
+	return 0;
+    /* Need to shutdown the ubik_client & other connections */
+    pr_End();
+    rx_Finalize();
+#endif /* SUPERGROUPS */
+
     return 0;
 }
 
@@ -240,22 +226,22 @@ CreateGroup(register struct cmd_syndesc *as)
 	if (idi) {
 	    code = util_GetInt32(idi->data, &id);
 	    if (code) {
-		afs_com_err(whoami, code, "because group id was: '%s'",
+		com_err(whoami, code, "because group id was: '%s'",
 			idi->data);
 		return code;
 	    }
 	    if (id >= 0) {
 		code = PRBADARG;
-		afs_com_err(whoami, code, "because group id %d was not negative",
+		com_err(whoami, code, "because group id %d was not negative",
 			id);
 		return code;
 	    }
-	    
-            if (id == 0) {
+#if defined(SUPERGROUPS)
+	    if (id == 0) {
 		printf("0 isn't a valid user id; aborting\n");
 		return EINVAL;
 	    }
-
+#endif
 	    idi = idi->next;
 	} else
 	    id = 0;
@@ -263,13 +249,13 @@ CreateGroup(register struct cmd_syndesc *as)
 	code = pr_CreateGroup(namei->data, owner, &id);
 	if (code) {
 	    if (owner || id)
-		afs_com_err(whoami, code,
+		com_err(whoami, code,
 			"; unable to create group %s with id %d%s%s%s%s",
 			namei->data, id, owner ? " owned by '" : "",
 			owner ? owner : "", owner ? "'" : "",
 			(force ? " (ignored)" : ""));
 	    else
-		afs_com_err(whoami, code, "; unable to create group %s %s",
+		com_err(whoami, code, "; unable to create group %s %s",
 			namei->data, (force ? "(ignored)" : ""));
 	    if (!force)
 		return code;
@@ -295,7 +281,7 @@ CreateUser(register struct cmd_syndesc *as)
 	if (idi) {
 	    code = util_GetInt32(idi->data, &id);
 	    if (code) {
-		afs_com_err(whoami, code, "because id was: '%s'", idi->data);
+		com_err(whoami, code, "because id was: '%s'", idi->data);
 		return code;
 	    }
 	    if (id == 0) {
@@ -309,11 +295,11 @@ CreateUser(register struct cmd_syndesc *as)
 	code = pr_CreateUser(namei->data, &id);
 	if (code) {
 	    if (id)
-		afs_com_err(whoami, code,
+		com_err(whoami, code,
 			"; unable to create user %s with id %d %s",
 			namei->data, id, (force ? "(ignored)" : ""));
 	    else
-		afs_com_err(whoami, code, "; unable to create user %s %s",
+		com_err(whoami, code, "; unable to create user %s %s",
 			namei->data, (force ? "(ignored)" : ""));
 	    if (!force)
 		return code;
@@ -335,11 +321,11 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
     int goodCount;
 
     if (!(as->parms[0].items || as->parms[1].items)) {
-	afs_com_err(whoami, 0, "must specify either a name or an id.");
+	com_err(whoami, 0, "must specify either a name or an id.");
 	return -1;
     }
     if (as->parms[0].items && as->parms[1].items) {
-	afs_com_err(whoami, 0, "can't specify both a name and id.");
+	com_err(whoami, 0, "can't specify both a name and id.");
 	return -1;
     }
 
@@ -368,11 +354,11 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 
 	code = pr_NameToId(nl, lids);
 	if (code)
-	    afs_com_err(whoami, code, "so couldn't look up names");
+	    com_err(whoami, code, "so couldn't look up names");
 	else {
 	    for (n = 0; n < lids->idlist_len; n++) {
 		if ((lids->idlist_val[n] == ANONYMOUSID)) {
-		    afs_com_err(whoami, PRNOENT, "so couldn't look up id for %s",
+		    com_err(whoami, PRNOENT, "so couldn't look up id for %s",
 			    nl->namelist_val[n]);
 		} else
 		    goodCount++;
@@ -394,7 +380,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 	for (i = as->parms[1].items; i; i = i->next) {
 	    code = util_GetInt32(i->data, &lids->idlist_val[n]);
 	    if (code)
-		afs_com_err(whoami, code =
+		com_err(whoami, code =
 			PRNOENT, "because a bogus id '%s' was specified",
 			i->data);
 	    n++;
@@ -404,7 +390,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 	    lnames->namelist_len = 0;
 	    code = pr_IdToName(lids, lnames);
 	    if (code)
-		afs_com_err(whoami, code, "translating ids");
+		com_err(whoami, code, "translating ids");
 	}
     }
     if (code) {
@@ -461,11 +447,11 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
     tids.idlist_val = 0;
     code = pr_NameToId(&names, &tids);
     if (code)
-	afs_com_err(whoami, code, "so couldn't look up names");
+	com_err(whoami, code, "so couldn't look up names");
     else {
 	for (n = 0; n < tids.idlist_len; n++) {
 	    if ((tids.idlist_val[n] == ANONYMOUSID)) {
-		afs_com_err(whoami, PRNOENT, "so couldn't look up id for %s",
+		com_err(whoami, PRNOENT, "so couldn't look up id for %s",
 			names.namelist_val[n]);
 	    } else
 		goodCount++;
@@ -484,7 +470,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 	tnames.namelist_len = 0;
 	code = pr_IdToName(&ids, &tnames);
 	if (code)
-	    afs_com_err(whoami, code, "translating ids");
+	    com_err(whoami, code, "translating ids");
 	else
 	    goodCount++;
 	if (lnames) {
@@ -515,7 +501,7 @@ AddToGroup(register struct cmd_syndesc *as)
 	for (g = as->parms[1].items; g; g = g->next) {
 	    code = pr_AddToGroup(u->data, g->data);
 	    if (code) {
-		afs_com_err(whoami, code,
+		com_err(whoami, code,
 			"; unable to add user %s to group %s %s", u->data,
 			g->data, (force ? "(ignored)" : ""));
 		if (!force)
@@ -536,7 +522,7 @@ RemoveFromGroup(register struct cmd_syndesc *as)
 	for (g = as->parms[1].items; g; g = g->next) {
 	    code = pr_RemoveUserFromGroup(u->data, g->data);
 	    if (code) {
-		afs_com_err(whoami, code,
+		com_err(whoami, code,
 			"; unable to remove user %s from group %s %s",
 			u->data, g->data, (force ? "(ignored)" : ""));
 		if (!force)
@@ -571,7 +557,7 @@ ListMembership(register struct cmd_syndesc *as)
 	list.namelist_len = 0;
 	code = pr_IDListMembers(ids.idlist_val[i], &list);
 	if (code) {
-	    afs_com_err(whoami, code, "; unable to get membership of %s (id: %d)",
+	    com_err(whoami, code, "; unable to get membership of %s (id: %d)",
 		    name, id);
 	    continue;
 	}
@@ -612,7 +598,7 @@ Delete(register struct cmd_syndesc *as)
 
 	code = pr_DeleteByID(id);
 	if (code) {
-	    afs_com_err(whoami, code, "deleting %s (id: %d) %s", name, id,
+	    com_err(whoami, code, "deleting %s (id: %d) %s", name, id,
 		    (force ? "(ignored)" : ""));
 	    if (!force)
 		return code;
@@ -660,7 +646,7 @@ CheckEntry(register struct cmd_syndesc *as)
 	code = pr_ListEntry(id, &aentry);
 	if (code) {
 	    rcode = code;
-	    afs_com_err(whoami, code, "; unable to find entry for (id: %d)", id);
+	    com_err(whoami, code, "; unable to find entry for (id: %d)", id);
 	    continue;
 	}
 
@@ -669,7 +655,7 @@ CheckEntry(register struct cmd_syndesc *as)
 	code = pr_IdToName(&lids, &lnames);
 	if (code) {
 	    rcode = code;
-	    afs_com_err(whoami, code,
+	    com_err(whoami, code,
 		    "translating owner (%d) and creator (%d) ids",
 		    aentry.owner, aentry.creator);
 	    continue;
@@ -750,7 +736,7 @@ ListEntries(struct cmd_syndesc *as)
 	    pr_ListEntries(flag, startindex, &nentries, &entriesp,
 			   &nextstartindex);
 	if (code) {
-	    afs_com_err(whoami, code, "; unable to list entries");
+	    com_err(whoami, code, "; unable to list entries\n");
 	    if (entriesp)
 		free(entriesp);
 	    break;
@@ -778,7 +764,7 @@ ChownGroup(register struct cmd_syndesc *as)
     owner = as->parms[1].items->data;
     code = pr_ChangeEntry(name, "", 0, owner);
     if (code)
-	afs_com_err(whoami, code, "; unable to change owner of %s to %s", name,
+	com_err(whoami, code, "; unable to change owner of %s to %s", name,
 		owner);
     return code;
 }
@@ -794,7 +780,7 @@ ChangeName(register struct cmd_syndesc *as)
     newname = as->parms[1].items->data;
     code = pr_ChangeEntry(oldname, newname, 0, "");
     if (code)
-	afs_com_err(whoami, code, "; unable to change name of %s to %s", oldname,
+	com_err(whoami, code, "; unable to change name of %s to %s", oldname,
 		newname);
     return code;
 }
@@ -807,11 +793,11 @@ ListMax(register struct cmd_syndesc *as)
 
     code = pr_ListMaxUserId(&maxUser);
     if (code)
-	afs_com_err(whoami, code, "getting maximum user id");
+	com_err(whoami, code, "getting maximum user id");
     else {
 	code = pr_ListMaxGroupId(&maxGroup);
 	if (code)
-	    afs_com_err(whoami, code, "getting maximum group id");
+	    com_err(whoami, code, "getting maximum group id");
 	else {
 	    printf("Max user id is %d and max group id is %d.\n", maxUser,
 		   maxGroup);
@@ -831,12 +817,12 @@ SetMax(register struct cmd_syndesc *as)
 	/* set user max */
 	code = util_GetInt32(as->parms[1].items->data, &maxid);
 	if (code) {
-	    afs_com_err(whoami, code, "because id was: '%s'",
+	    com_err(whoami, code, "because id was: '%s'",
 		    as->parms[1].items->data);
 	} else {
 	    code = pr_SetMaxUserId(maxid);
 	    if (code)
-		afs_com_err(whoami, code, "so couldn't set Max User Id to %d",
+		com_err(whoami, code, "so couldn't set Max User Id to %d",
 			maxid);
 	}
     }
@@ -844,12 +830,12 @@ SetMax(register struct cmd_syndesc *as)
 	/* set group max */
 	code = util_GetInt32(as->parms[0].items->data, &maxid);
 	if (code) {
-	    afs_com_err(whoami, code, "because id was: '%s'",
+	    com_err(whoami, code, "because id was: '%s'",
 		    as->parms[0].items->data);
 	} else {
 	    code = pr_SetMaxGroupId(maxid);
 	    if (code)
-		afs_com_err(whoami, code, "so couldn't set Max Group Id to %d",
+		com_err(whoami, code, "so couldn't set Max Group Id to %d",
 			maxid);
 	}
     }
@@ -918,7 +904,7 @@ SetFields(register struct cmd_syndesc *as)
     if (as->parms[2].items) {	/* limitgroups */
 	code = util_GetInt32(as->parms[2].items->data, &ngroups);
 	if (code) {
-	    afs_com_err(whoami, code, "because ngroups was: '%s'",
+	    com_err(whoami, code, "because ngroups was: '%s'",
 		    as->parms[2].items->data);
 	    return code;
 	}
@@ -928,7 +914,7 @@ SetFields(register struct cmd_syndesc *as)
     if (as->parms[3].items) {	/* limitgroups */
 	code = util_GetInt32(as->parms[3].items->data, &nusers);
 	if (code) {
-	    afs_com_err(whoami, code, "because nusers was: '%s'",
+	    com_err(whoami, code, "because nusers was: '%s'",
 		    as->parms[3].items->data);
 	    return code;
 	}
@@ -943,7 +929,7 @@ SetFields(register struct cmd_syndesc *as)
 	    continue;
 	code = pr_SetFieldsEntry(id, mask, flags, ngroups, nusers);
 	if (code) {
-	    afs_com_err(whoami, code, "; unable to set fields for %s (id: %d)",
+	    com_err(whoami, code, "; unable to set fields for %s (id: %d)",
 		    name, id);
 	    return code;
 	}
@@ -985,7 +971,7 @@ ListOwned(register struct cmd_syndesc *as)
 	    list.namelist_len = 0;
 	    code = pr_ListOwned(oid, &list, &more);
 	    if (code) {
-		afs_com_err(whoami, code,
+		com_err(whoami, code,
 			"; unable to get owner list for %s (id: %d)", name,
 			oid);
 		break;
@@ -1018,10 +1004,6 @@ add_std_args(register struct cmd_syndesc *ts)
     cmd_AddParm(ts, "-test", CMD_FLAG, CMD_OPTIONAL | CMD_HIDE, test_help);
     cmd_AddParm(ts, "-force", CMD_FLAG, CMD_OPTIONAL,
 		"Continue oper despite reasonable errors");
-    cmd_AddParm(ts, "-localauth", CMD_FLAG, CMD_OPTIONAL,
-		"use local authentication");
-    cmd_AddParm(ts, "-auth", CMD_FLAG, CMD_OPTIONAL,
-		"use user's authentication (default)");
 }
 
 /*
@@ -1040,14 +1022,13 @@ main(int argc, char **argv)
 {
     register afs_int32 code;
     register struct cmd_syndesc *ts;
-
+#if defined(SUPERGROUPS)
     char line[2048];
     char *cp, *lastp;
     int parsec;
     char *parsev[CMD_MAXPARMS];
     char *savec;
-    struct authstate state;
-
+#endif
 #ifdef WIN32
     WSADATA WSAjunk;
 #endif
@@ -1071,10 +1052,7 @@ main(int argc, char **argv)
     sigaction(SIGSEGV, &nsa, NULL);
 #endif
 
-    memset(&state, 0, sizeof(state));
-    state.sec = 1; /* default is auth */
-
-    ts = cmd_CreateSyntax("creategroup", CreateGroup, NULL,
+    ts = cmd_CreateSyntax("creategroup", CreateGroup, 0,
 			  "create a new group");
     cmd_AddParm(ts, "-name", CMD_LIST, 0, "group name");
     cmd_AddParm(ts, "-owner", CMD_SINGLE, CMD_OPTIONAL, "owner of the group");
@@ -1083,60 +1061,60 @@ main(int argc, char **argv)
     add_std_args(ts);
     cmd_CreateAlias(ts, "cg");
 
-    ts = cmd_CreateSyntax("createuser", CreateUser, NULL, "create a new user");
+    ts = cmd_CreateSyntax("createuser", CreateUser, 0, "create a new user");
     cmd_AddParm(ts, "-name", CMD_LIST, 0, "user name");
     cmd_AddParm(ts, "-id", CMD_LIST, CMD_OPTIONAL, "user id");
     add_std_args(ts);
     cmd_CreateAlias(ts, "cu");
 
-    ts = cmd_CreateSyntax("adduser", AddToGroup, NULL, "add a user to a group");
+    ts = cmd_CreateSyntax("adduser", AddToGroup, 0, "add a user to a group");
     cmd_AddParm(ts, "-user", CMD_LIST, 0, "user name");
     cmd_AddParm(ts, "-group", CMD_LIST, 0, "group name");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("removeuser", RemoveFromGroup, NULL,
+    ts = cmd_CreateSyntax("removeuser", RemoveFromGroup, 0,
 			  "remove a user from a group");
     cmd_AddParm(ts, "-user", CMD_LIST, 0, "user name");
     cmd_AddParm(ts, "-group", CMD_LIST, 0, "group name");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("membership", ListMembership, NULL,
+    ts = cmd_CreateSyntax("membership", ListMembership, 0,
 			  "list membership of a user or group");
     cmd_AddParm(ts, "-nameorid", CMD_LIST, 0, "user or group name or id");
     add_std_args(ts);
     cmd_CreateAlias(ts, "groups");
 
-    ts = cmd_CreateSyntax("delete", Delete, NULL,
+    ts = cmd_CreateSyntax("delete", Delete, 0,
 			  "delete a user or group from database");
     cmd_AddParm(ts, "-nameorid", CMD_LIST, 0, "user or group name or id");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("examine", CheckEntry, NULL, "examine an entry");
+    ts = cmd_CreateSyntax("examine", CheckEntry, 0, "examine an entry");
     cmd_AddParm(ts, "-nameorid", CMD_LIST, 0, "user or group name or id");
     add_std_args(ts);
     cmd_CreateAlias(ts, "check");
 
-    ts = cmd_CreateSyntax("chown", ChownGroup, NULL,
+    ts = cmd_CreateSyntax("chown", ChownGroup, 0,
 			  "change ownership of a group");
     cmd_AddParm(ts, "-name", CMD_SINGLE, 0, "group name");
     cmd_AddParm(ts, "-owner", CMD_SINGLE, 0, "new owner");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("rename", ChangeName, NULL, "rename user or group");
+    ts = cmd_CreateSyntax("rename", ChangeName, 0, "rename user or group");
     cmd_AddParm(ts, "-oldname", CMD_SINGLE, 0, "old name");
     cmd_AddParm(ts, "-newname", CMD_SINGLE, 0, "new name");
     add_std_args(ts);
     cmd_CreateAlias(ts, "chname");
 
-    ts = cmd_CreateSyntax("listmax", ListMax, NULL, "list max id");
+    ts = cmd_CreateSyntax("listmax", ListMax, 0, "list max id");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("setmax", SetMax, NULL, "set max id");
+    ts = cmd_CreateSyntax("setmax", SetMax, 0, "set max id");
     cmd_AddParm(ts, "-group", CMD_SINGLE, CMD_OPTIONAL, "group max");
     cmd_AddParm(ts, "-user", CMD_SINGLE, CMD_OPTIONAL, "user max");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("setfields", SetFields, NULL,
+    ts = cmd_CreateSyntax("setfields", SetFields, 0,
 			  "set fields for an entry");
     cmd_AddParm(ts, "-nameorid", CMD_LIST, 0, "user or group name or id");
     cmd_AddParm(ts, "-access", CMD_SINGLE, CMD_OPTIONAL, "set privacy flags");
@@ -1148,42 +1126,47 @@ main(int argc, char **argv)
 #endif
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("listowned", ListOwned, NULL,
+    ts = cmd_CreateSyntax("listowned", ListOwned, 0,
 			  "list groups owned by an entry or zero id gets orphaned groups");
     cmd_AddParm(ts, "-nameorid", CMD_LIST, 0, "user or group name or id");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("listentries", ListEntries, NULL,
+    ts = cmd_CreateSyntax("listentries", ListEntries, 0,
 			  "list users/groups in the protection database");
     cmd_AddParm(ts, "-users", CMD_FLAG, CMD_OPTIONAL, "list user entries");
     cmd_AddParm(ts, "-groups", CMD_FLAG, CMD_OPTIONAL, "list group entries");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("interactive", pts_Interactive, NULL,
+#if defined(SUPERGROUPS)
+
+    ts = cmd_CreateSyntax("interactive", Interactive, 0,
 			  "enter interactive mode");
     add_std_args(ts);
     cmd_CreateAlias(ts, "in");
 
-    ts = cmd_CreateSyntax("quit", pts_Quit, NULL, "exit program");
+    ts = cmd_CreateSyntax("quit", Quit, 0, "exit program");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("source", pts_Source, NULL, "read commands from file");
+    ts = cmd_CreateSyntax("source", Source, 0, "read commands from file");
     cmd_AddParm(ts, "-file", CMD_SINGLE, 0, "filename");
     add_std_args(ts);
 
-    ts = cmd_CreateSyntax("sleep", pts_Sleep, NULL, "pause for a bit");
+    ts = cmd_CreateSyntax("sleep", Sleep, 0, "pause for a bit");
     cmd_AddParm(ts, "-delay", CMD_SINGLE, 0, "seconds");
     add_std_args(ts);
 
-    cmd_SetBeforeProc(GetGlobals, &state);
+#endif /* SUPERGROUPS */
 
+    cmd_SetBeforeProc(GetGlobals, 0);
+
+#if defined(SUPERGROUPS)
     finished = 1;
-    source = NULL;
     if (code = cmd_Dispatch(argc, argv)) {
-	CleanUp(NULL, NULL);
+	CleanUp(0);
 	exit(1);
     }
-    while (source && !finished) {
+    source = stdin;
+    while (!finished) {
 	if (isatty(fileno(source)))
 	    fprintf(stderr, "pts> ");
 	if (!fgets(line, sizeof line, source)) {
@@ -1205,7 +1188,7 @@ main(int argc, char **argv)
 	    cmd_ParseLine(line, parsev, &parsec,
 			  sizeof(parsev) / sizeof(*parsev));
 	if (code) {
-	    afs_com_err(whoami, code, "parsing line: <%s>", line);
+	    com_err(whoami, code, "parsing line: <%s>", line);
 	    exit(2);
 	}
 	savec = parsev[0];
@@ -1214,7 +1197,13 @@ main(int argc, char **argv)
 	parsev[0] = savec;
 	cmd_FreeArgv(parsev);
     }
-    CleanUp(NULL, NULL);
+    CleanUp(0);
     exit(0);
-}
 
+#else /* SUPERGROUPS */
+
+    cmd_SetAfterProc(CleanUp, 0);
+    code = cmd_Dispatch(argc, argv);
+    exit(code != 0);
+#endif /* SUPERGROUPS */
+}
