@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/viced/host.c,v 1.57.2.29 2006/03/30 16:29:22 shadow Exp $");
+    ("$Header: /cvs/openafs/src/viced/host.c,v 1.76 2006/02/13 17:09:36 jaltman Exp $");
 
 #include <stdio.h>
 #include <errno.h>
@@ -198,11 +198,6 @@ GetHTBlock()
     register int i;
     static int index = 0;
 
-    if (HTBlocks == h_MAXHOSTTABLES) {
-	ViceLog(0, ("h_MAXHOSTTABLES reached\n"));
-	ShutDownAndCore(PANIC);
-    }
-
     block = (struct HTBlock *)malloc(sizeof(struct HTBlock));
     if (!block) {
 	ViceLog(0, ("Failed malloc in GetHTBlock\n"));
@@ -450,7 +445,7 @@ h_gethostcps_r(register struct host *host, register afs_int32 now)
     slept ? (host->cpsCall = FT_ApproxTime()) : (host->cpsCall = now);
 
     H_UNLOCK;
-    code = pr_GetHostCPS(ntohl(host->host), &host->hcps);
+    code = pr_GetHostCPS(htonl(host->host), &host->hcps);
     H_LOCK;
     if (code) {
 	/*
@@ -504,7 +499,7 @@ h_gethostcps_r(register struct host *host, register afs_int32 now)
 
 /* args in net byte order */
 void
-h_flushhostcps(register afs_uint32 hostaddr, register afs_uint16 hport)
+h_flushhostcps(register afs_uint32 hostaddr, register afs_uint32 hport)
 {
     register struct host *host;
     int held = 0;
@@ -531,20 +526,29 @@ struct host *
 h_Alloc_r(register struct rx_connection *r_con)
 {
     struct servent *serverentry;
+    register index = h_HashIndex(rxr_HostOf(r_con));
     register struct host *host;
     static struct rx_securityClass *sc = 0;
     afs_int32 now;
+    struct h_hashChain *h_hashChain;
 #if FS_STATS_DETAILED
     afs_uint32 newHostAddr_HBO;	/*New host IP addr, in host byte order */
 #endif /* FS_STATS_DETAILED */
 
     host = GetHT();
 
+    h_hashChain = (struct h_hashChain *)malloc(sizeof(struct h_hashChain));
+    if (!h_hashChain) {
+	ViceLog(0, ("Failed malloc in h_Alloc_r\n"));
+	assert(0);
+    }
+    h_hashChain->hostPtr = host;
+    h_hashChain->addr = rxr_HostOf(r_con);
+    h_hashChain->next = hostHashTable[index];
+    hostHashTable[index] = h_hashChain;
+
     host->host = rxr_HostOf(r_con);
     host->port = rxr_PortOf(r_con);
-
-    hashInsert_r(host->host, host->port, host);
-
     if (consolePort == 0) {	/* find the portal number for console */
 #if	defined(AFS_OSF_ENV)
 	serverentry = getservbyname("ropcons", "");
@@ -600,7 +604,7 @@ h_Alloc_r(register struct rx_connection *r_con)
 /* Note: host should be released by caller if 0 == *heldp and non-null */
 /* hostaddr and hport are in network order */
 struct host *
-h_Lookup_r(afs_uint32 haddr, afs_uint16 hport, int *heldp)
+h_Lookup_r(afs_uint32 haddr, afs_uint32 hport, int *heldp)
 {
     register afs_int32 now;
     register struct host *host = 0;
@@ -704,38 +708,26 @@ h_TossStuff_r(register struct host *host)
     /* ASSUMPTION: rxi_FreeConnection() does not yield */
     for (cp = &host->FirstClient; (client = *cp);) {
 	if ((host->hostFlags & HOSTDELETED) || client->deleted) {
-	    int code;
-	    ObtainWriteLockNoBlock(&client->lock, code);
-	    if (code < 0) {
-		char hoststr[16];
-		ViceLog(0,
-			("Warning: h_TossStuff_r failed: Host %s:%d client %x was locked.\n",
-			 afs_inet_ntoa_r(host->host, hoststr),
-			 ntohs(host->port), client));
-		return;
-	    }
-		 
 	    if (client->refCount) {
 		char hoststr[16];
 		ViceLog(0,
-			("Warning: h_TossStuff_r failed: Host %s:%d client %x refcount %d.\n",
+			("Warning: Host %s:%d client %x refcount %d while deleting, failing.\n",
 			 afs_inet_ntoa_r(host->host, hoststr),
 			 ntohs(host->port), client, client->refCount));
 		/* This is the same thing we do if the host is locked */
-		ReleaseWriteLock(&client->lock);
 		return;
 	    }
+	    /* We can't protect this without dropping the H_LOCK */
 	    client->CPS.prlist_len = 0;
-	    if ((client->ViceId != ANONYMOUSID) && client->CPS.prlist_val)
+	    if ((client->ViceId != ANONYMOUSID) && client->CPS.prlist_val) {
 		free(client->CPS.prlist_val);
-	    client->CPS.prlist_val = NULL;
+		client->CPS.prlist_val = NULL;
+	    }
 	    if (client->tcon) {
 		rx_SetSpecific(client->tcon, rxcon_client_key, (void *)0);
-		rx_PutConnection(client->tcon);
 	    }
 	    CurrentConnections--;
 	    *cp = client->next;
-	    ReleaseWriteLock(&client->lock);
 	    FreeCE(client);
 	} else
 	    cp = &client->next;
@@ -762,10 +754,8 @@ h_TossStuff_r(register struct host *host)
 	     * destroying the connection.
 	     */
 	    client = rx_GetSpecific(rxconn, rxcon_client_key);
-	    if (client && client->tcon == rxconn) {
-		rx_PutConnection(client->tcon);
+	    if (client && client->tcon == rxconn)
 		client->tcon = NULL;
-	    }
 	    rx_SetSpecific(rxconn, rxcon_client_key, (void *)0);
 	    rx_DestroyConnection(rxconn);
 	}
@@ -834,10 +824,8 @@ h_FreeConnection(struct rx_connection *tcon)
     client = (struct client *)rx_GetSpecific(tcon, rxcon_client_key);
     if (client) {
 	H_LOCK;
-	if (client->tcon == tcon) {
-	    rx_PutConnection(client->tcon);
+	if (client->tcon == tcon)
 	    client->tcon = (struct rx_connection *)0;
-	}
 	H_UNLOCK;
     }
     return 0;
@@ -911,10 +899,10 @@ h_Enumerate_r(int (*proc) (), struct host *enumstart, char *param)
     if (enumstart && !(held = h_Held_r(enumstart)))
 	h_Hold_r(enumstart); 
     for (host = enumstart; host; host = next, held = nheld) {
+	held = (*proc) (host, held, param);
 	next = host->next;
 	if (next && !(nheld = h_Held_r(next)))
 	    h_Hold_r(next);
-	held = (*proc) (host, held, param);
 	if (!held)
 	    h_Release_r(host); /* this might free up the host */
     }
@@ -987,7 +975,7 @@ addInterfaceAddr_r(struct host *host, afs_uint32 addr, afs_uint16 port)
     assert(host);
     assert(host->interface);
 
-    ViceLog(125, ("addInterfaceAddr : host %s:%d addr %s:%d\n", 
+    ViceLog(125, ("addInterfaceAddr : host %s:d addr %s:%d\n", 
 		   afs_inet_ntoa_r(host->host, hoststr), ntohs(host->port), 
 		   afs_inet_ntoa_r(addr, hoststr2), ntohs(port)));
 
@@ -1093,8 +1081,8 @@ h_GetHost_r(struct rx_connection *tcon)
     struct interfaceAddr interf;
     int interfValid = 0;
     struct Identity *identP = NULL;
-    afs_uint32 haddr;
-    afs_uint16 hport;
+    afs_int32 haddr;
+    afs_int16 hport;
     char hoststr[16], hoststr2[16];
     Capabilities caps;
     struct rx_connection *cb_conn = NULL;
@@ -1197,7 +1185,7 @@ h_GetHost_r(struct rx_connection *tcon)
 	    host->hostFlags |= VENUSDOWN;
 	}
 	if (caps.Capabilities_val
-	    && (caps.Capabilities_val[0] & CAPABILITY_ERRORTRANS))
+	    && (caps.Capabilities_val[0] & CLIENT_CAPABILITY_ERRORTRANS))
 	    host->hostFlags |= HERRORTRANS;
 	else
 	    host->hostFlags &= ~(HERRORTRANS);
@@ -1392,10 +1380,9 @@ h_GetHost_r(struct rx_connection *tcon)
 		    }
 		    host->hostFlags |= HOSTDELETED;
 		    h_Unlock_r(host);
-		    /* release host because it was allocated by h_Alloc_r */
-		    h_Release_r(host);
+		    if (!held)
+			h_Release_r(host);
 		    host = oldHost;
-		    /* the new host is held and locked */
 		} else {
 		    /* This really is a new host */
 		    hashInsertUuid_r(&identP->uuid, host);
@@ -1432,7 +1419,7 @@ h_GetHost_r(struct rx_connection *tcon)
 	    }
 	}
 	if (caps.Capabilities_val
-	    && (caps.Capabilities_val[0] & CAPABILITY_ERRORTRANS))
+	    && (caps.Capabilities_val[0] & CLIENT_CAPABILITY_ERRORTRANS))
 	    host->hostFlags |= HERRORTRANS;
 	else
 	    host->hostFlags &= ~(HERRORTRANS);
@@ -1449,20 +1436,34 @@ h_GetHost_r(struct rx_connection *tcon)
 
 
 static char localcellname[PR_MAXNAMELEN + 1];
-char local_realm[AFS_REALM_SZ] = "";
+char local_realms[AFS_NUM_LREALMS][AFS_REALM_SZ];
+int  num_lrealms = -1;
 
 /* not reentrant */
 void
 h_InitHostPackage()
 {
     afsconf_GetLocalCell(confDir, localcellname, PR_MAXNAMELEN);
-    if (!local_realm[0]) {
-	if (afs_krb_get_lrealm(local_realm, 0) != 0 /*KSUCCESS*/) {
+    if (num_lrealms == -1) {
+	int i;
+	for (i=0; i<AFS_NUM_LREALMS; i++) {
+	    if (afs_krb_get_lrealm(local_realms[i], i) != 0 /*KSUCCESS*/)
+		break;
+	}
+
+	if (i=0) {
 	    ViceLog(0,
 		    ("afs_krb_get_lrealm failed, using %s.\n",
 		     localcellname));
-	    strcpy(local_realm, localcellname);
+	    strncpy(local_realms[0], localcellname, AFS_REALM_SZ);
+	    num_lrealms = i =1;
+	} else {
+	    num_lrealms = i;
 	}
+
+	/* initialize the rest of the local realms to nullstring for debugging */
+	for (; i<AFS_NUM_LREALMS; i++)
+	    local_realms[i][0] = '\0';
     }
     rxcon_ident_key = rx_KeyCreate((rx_destructor_t) free);
     rxcon_client_key = rx_KeyCreate((rx_destructor_t) 0);
@@ -1492,11 +1493,10 @@ MapName_r(char *aname, char *acell, afs_int32 * aval)
 
     cnamelen = strlen(acell);
     if (cnamelen) {
-	if (strcasecmp(local_realm, acell)
-	    && strcasecmp(localcellname, acell)) {
+	if (afs_is_foreign_ticket_name(aname, "", acell, localcellname)) {
 	    ViceLog(2,
-		    ("MapName: cell is foreign.  cell=%s, localcell=%s, localrealm=%s\n",
-		     acell, localcellname, local_realm));
+		    ("MapName: cell is foreign.  cell=%s, localcell=%s, localrealms={%s,%s,%s,%s}\n",
+		    acell, localcellname, local_realms[0],local_realms[1],local_realms[2],local_realms[3]));
 	    if ((anamelen + cnamelen + 1) >= PR_MAXNAMELEN) {
 		ViceLog(2,
 			("MapName: Name too long, using AnonymousID for %s@%s\n",
@@ -1546,7 +1546,7 @@ MapName_r(char *aname, char *acell, afs_int32 * aval)
 /*MapName*/
 
 
-/* NOTE: this returns the client with a Write lock and a refCount */
+/* NOTE: this returns the client with a Write lock */
 struct client *
 h_ID2Client(afs_int32 vid)
 {
@@ -1562,6 +1562,9 @@ h_ID2Client(afs_int32 vid)
 		client->refCount++;
 		H_UNLOCK;
 		ObtainWriteLock(&client->lock);
+		H_LOCK;
+		client->refCount--;
+		H_UNLOCK;
 		return client;
 	    }
 	}
@@ -1577,9 +1580,6 @@ h_ID2Client(afs_int32 vid)
  * isn't around. The client is returned with its reference count incremented
  * by one. The caller must call h_ReleaseClient_r when finished with
  * the client.
- *
- * the client->host is returned held.  h_ReleaseClient_r does not release
- * the hold on client->host.
  */
 struct client *
 h_FindClient_r(struct rx_connection *tcon)
@@ -1684,15 +1684,14 @@ h_FindClient_r(struct rx_connection *tcon)
 			(struct client *)rx_GetSpecific(client->tcon,
 							rxcon_client_key);
 		    if (oldClient) {
-			if (oldClient == client) {
+			if (oldClient == client)
 			    rx_SetSpecific(client->tcon, rxcon_client_key,
 					   NULL);
-			} else
+			else
 			    ViceLog(0,
 				    ("Client-conn mismatch: CL1=%x, CN=%x, CL2=%x\n",
 				     client, client->tcon, oldClient));
 		    }
-		    rx_PutConnection(client->tcon);
 		    client->tcon = (struct rx_connection *)0;
 		}
 		client->refCount++;
@@ -1735,10 +1734,11 @@ h_FindClient_r(struct rx_connection *tcon)
     client->prfail = fail;
 
     if (!(client->CPS.prlist_val) || (viceid != client->ViceId)) {
-	client->CPS.prlist_len = 0;
-	if (client->CPS.prlist_val && (client->ViceId != ANONYMOUSID))
+	if (client->CPS.prlist_val && (client->ViceId != ANONYMOUSID)) {
 	    free(client->CPS.prlist_val);
+	}
 	client->CPS.prlist_val = NULL;
+	client->CPS.prlist_len = 0;
 	client->ViceId = viceid;
 	client->expTime = expTime;
 
@@ -1797,9 +1797,10 @@ h_FindClient_r(struct rx_connection *tcon)
 			    afs_inet_ntoa_r(rxr_HostOf(tcon), hoststr),
 			    ntohs(rxr_PortOf(tcon)),
 			    oldClient, oldClient->sid));
-		if ((client->ViceId != ANONYMOUSID) && client->CPS.prlist_val)
+		if ((client->ViceId != ANONYMOUSID) && client->CPS.prlist_val) {
 		    free(client->CPS.prlist_val);
-		client->CPS.prlist_val = NULL;
+		    client->CPS.prlist_val = NULL;
+		}
 		client->CPS.prlist_len = 0;
 		if (client->tcon) {
 		    rx_SetSpecific(client->tcon, rxcon_client_key, (void *)0);
@@ -1816,7 +1817,6 @@ h_FindClient_r(struct rx_connection *tcon)
 	    oldClient->refCount++;
 	    client = oldClient;
 	} else {
-	    rx_PutConnection(oldClient->tcon);
 	    oldClient->tcon = (struct rx_connection *)0;
 	    ViceLog(0, ("FindClient: deleted client %x(%x) already had conn %x (host %s:%d), stolen by client %x(%x)\n", 
 			oldClient, oldClient->sid, tcon, 
@@ -1834,7 +1834,6 @@ h_FindClient_r(struct rx_connection *tcon)
 	h_Unlock_r(host);
 	CurrentConnections++;	/* increment number of connections */
     }
-    rx_GetConnection(tcon);
     client->tcon = tcon;
     rx_SetSpecific(tcon, rxcon_client_key, client);
     ReleaseWriteLock(&client->lock);
