@@ -13,7 +13,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vol/namei_ops.c,v 1.21.2.3 2004/11/09 17:16:40 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vol/namei_ops.c,v 1.27 2005/11/01 16:42:47 shadow Exp $");
 
 #ifdef AFS_NAMEI_ENV
 #include <stdio.h>
@@ -30,7 +30,7 @@ RCSID
 #ifdef AFS_AIX_ENV
 #include <sys/lockf.h>
 #endif
-#ifdef AFS_SUN5_ENV
+#if defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
 #include <unistd.h>
 #endif
 #include <afs/afsutil.h>
@@ -860,7 +860,7 @@ namei_GetLinkCount(FdHandle_t * h, Inode ino, int lockit)
     namei_GetLCOffsetAndIndexFromIno(ino, &offset, &index);
 
     if (lockit) {
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
 	if (lockf(h->fd_fd, F_LOCK, 0) < 0)
 #else
 	if (flock(h->fd_fd, LOCK_EX) < 0)
@@ -879,7 +879,7 @@ namei_GetLinkCount(FdHandle_t * h, Inode ino, int lockit)
 
   bad_getLinkByte:
     if (lockit)
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
 	lockf(h->fd_fd, F_ULOCK, 0);
 #else
 	flock(h->fd_fd, LOCK_UN);
@@ -904,7 +904,7 @@ GetFreeTag(IHandle_t * ih, int vno)
 	return -1;
 
     /* Only one manipulates at a time. */
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
     if (lockf(fdP->fd_fd, F_LOCK, 0) < 0) {
 #else
     if (flock(fdP->fd_fd, LOCK_EX) < 0) {
@@ -944,7 +944,7 @@ GetFreeTag(IHandle_t * ih, int vno)
 	goto badGetFreeTag;
     }
     FDH_SYNC(fdP);
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
     lockf(fdP->fd_fd, F_ULOCK, 0);
 #else
     flock(fdP->fd_fd, LOCK_UN);
@@ -953,7 +953,7 @@ GetFreeTag(IHandle_t * ih, int vno)
     return col;;
 
   badGetFreeTag:
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
     lockf(fdP->fd_fd, F_ULOCK, 0);
 #else
     flock(fdP->fd_fd, LOCK_UN);
@@ -980,7 +980,7 @@ namei_SetLinkCount(FdHandle_t * fdP, Inode ino, int count, int locked)
     namei_GetLCOffsetAndIndexFromIno(ino, &offset, &index);
 
     if (!locked) {
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
 	if (lockf(fdP->fd_fd, F_LOCK, 0) < 0) {
 #else
 	if (flock(fdP->fd_fd, LOCK_EX) < 0) {
@@ -1023,7 +1023,7 @@ namei_SetLinkCount(FdHandle_t * fdP, Inode ino, int count, int locked)
 
 
   bad_SetLinkCount:
-#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV)
     lockf(fdP->fd_fd, F_ULOCK, 0);
 #else
     flock(fdP->fd_fd, LOCK_UN);
