@@ -15,13 +15,20 @@
  */
 #include <afsconfig.h>
 #include <afs/param.h>
+#define MAXINT     (~(1<<((sizeof(int)*8)-1)))
 
 RCSID
-    ("$Header: /cvs/openafs/src/vol/vnode.c,v 1.19.2.7 2009/02/17 04:37:59 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vol/vnode.c,v 1.26 2005/10/19 18:23:19 shadow Exp $");
 
 #include <errno.h>
 #include <stdio.h>
+#ifdef HAVE_STRING_H
 #include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #ifdef AFS_PTHREAD_ENV
 #include <assert.h>
 #else /* AFS_PTHREAD_ENV */
@@ -69,8 +76,6 @@ private int moveHash(register Vnode * vnp, bit32 newHash);
 void StickOnLruChain_r(register Vnode * vnp,
 		       register struct VnodeClassInfo *vcp);
 
-extern int LogLevel;
-
 #define BAD_IGET	-1000
 
 /* There are two separate vnode queue types defined here:
@@ -715,7 +720,11 @@ VPutVnode_r(Error * ec, register Vnode * vnp)
 		vnp->disk.serverModifyTime = now;
 	    }
 	    if (vnp->changed_newTime)
+	    {
 		V_updateDate(vp) = vp->updateTime = now;
+		if(V_volUpCounter(vp)<MAXINT)
+			V_volUpCounter(vp)++;
+	    }
 
 	    /* The vnode has been changed. Write it out to disk */
 	    if (!V_inUse(vp)) {
@@ -959,7 +968,6 @@ VCloseVnodeFiles_r(Volume * vp)
 	for (vnp = VnodeHashTable[i]; vnp; vnp = vnp->hashNext) {
 	    if (vnp->volumePtr == vp) {
 		IH_REALLYCLOSE(vnp->handle);
-		IH_RELEASE(vnp->handle);
 	    }
 	}
     }
