@@ -20,7 +20,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vol/volume.c,v 1.34 2003/11/22 02:43:19 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vol/volume.c,v 1.41 2005/05/30 10:49:30 jaltman Exp $");
 
 #include <rx/xdr.h>
 #include <afs/afsint.h>
@@ -152,6 +152,7 @@ pthread_mutex_t vol_fsync_mutex;
 pthread_mutex_t vol_trans_mutex;
 pthread_cond_t vol_put_volume_cond;
 pthread_cond_t vol_sleep_cond;
+int vol_attach_threads = 1;
 #endif /* AFS_PTHREAD_ENV */
 
 #ifdef	AFS_OSF_ENV
@@ -209,6 +210,20 @@ ffs(x)
 }
 #endif /* !AFS_HAVE_FFS */
 
+#ifdef AFS_PTHREAD_ENV
+#include "rx/rx_queue.h"
+typedef struct diskpartition_queue_t {
+    struct rx_queue queue;
+    struct DiskPartition * diskP;
+} diskpartition_queue_t;
+typedef struct vinitvolumepackage_thread_t {
+    struct rx_queue queue;
+    pthread_cond_t thread_done_cv;
+    int n_threads_complete;
+} vinitvolumepackage_thread_t;
+static void * VInitVolumePackageThread(void * args);
+#endif /* AFS_PTHREAD_ENV */
+
 struct Lock vol_listLock;	/* Lock obtained when listing volumes:  prevents a volume from being missed if the volume is attached during a list volumes */
 
 extern struct Lock FSYNC_handler_lock;
@@ -229,7 +244,8 @@ int VInit;			/* 0 - uninitialized,
 bit32 VolumeCacheCheck;		/* Incremented everytime a volume goes on line--
 				 * used to stamp volume headers and in-core
 				 * vnodes.  When the volume goes on-line the
-				 * vnode will be invalidated */
+				 * vnode will be invalidated
+				 * access only with VOL_LOCK held */
 
 int VolumeCacheSize = 200, VolumeGets = 0, VolumeReplacements = 0, Vlooks = 0;
 
@@ -284,10 +300,48 @@ VInitVolumePackage(ProgramType pt, int nLargeVnodes, int nSmallVnodes,
 	return -1;
 
     if (programType == fileServer) {
+	struct DiskPartition *diskP;
+#ifdef AFS_PTHREAD_ENV
+	struct vinitvolumepackage_thread_t params;
+	struct diskpartition_queue_t * dpq;
+	int i, len;
+	pthread_t tid;
+	pthread_attr_t attrs;
+
+	assert(pthread_cond_init(&params.thread_done_cv,NULL) == 0);
+	queue_Init(&params);
+	params.n_threads_complete = 0;
+
+	/* create partition work queue */
+	for (len=0, diskP = DiskPartitionList; diskP; diskP = diskP->next, len++) {
+	    dpq = (diskpartition_queue_t *) malloc(sizeof(struct diskpartition_queue_t));
+	    assert(dpq != NULL);
+	    dpq->diskP = diskP;
+	    queue_Prepend(&params,dpq);
+	}
+
+	assert(pthread_attr_init(&attrs) == 0);
+	assert(pthread_attr_setdetachstate(&attrs, PTHREAD_CREATE_DETACHED) == 0);
+
+	len = MIN(len, vol_attach_threads);
+	
+	VOL_LOCK;
+	for (i=0; i < len; i++) {
+	    assert(pthread_create
+		   (&tid, &attrs, &VInitVolumePackageThread,
+		    &params) == 0);
+	}
+
+	while(params.n_threads_complete < len) {
+  	    pthread_cond_wait(&params.thread_done_cv,&vol_glock_mutex);
+	}
+	VOL_UNLOCK;
+
+	assert(pthread_cond_destroy(&params.thread_done_cv) == 0);
+
+#else /* AFS_PTHREAD_ENV */
 	DIR *dirp;
 	struct dirent *dp;
-	struct DiskPartition *diskP;
-
 
 	/* Attach all the volumes in this partition */
 	for (diskP = DiskPartitionList; diskP; diskP = diskP->next) {
@@ -319,18 +373,81 @@ VInitVolumePackage(ProgramType pt, int nLargeVnodes, int nSmallVnodes,
 	    Log("Partition %s: attached %d volumes; %d volumes not attached\n", diskP->name, nAttached, nUnattached);
 	    closedir(dirp);
 	}
+#endif /* AFS_PTHREAD_ENV */
     }
 
     VInit = 2;			/* Initialized, and all volumes have been attached */
     if (programType == volumeUtility && connect) {
 	if (!VConnectFS()) {
 	    Log("Unable to connect to file server; aborted\n");
+	    Lock_Destroy(&FSYNC_handler_lock);
 	    exit(1);
 	}
     }
     return 0;
 }
 
+#ifdef AFS_PTHREAD_ENV
+static void *
+VInitVolumePackageThread(void * args) {
+    int errors = 0;		/* Number of errors while finding vice partitions. */
+
+    DIR *dirp;
+    struct dirent *dp;
+    struct DiskPartition *diskP;
+    struct vinitvolumepackage_thread_t * params;
+    struct diskpartition_queue_t * dpq;
+
+    params = (vinitvolumepackage_thread_t *) args;
+
+
+    VOL_LOCK;
+    /* Attach all the volumes in this partition */
+    while (queue_IsNotEmpty(params)) {
+        int nAttached = 0, nUnattached = 0;
+
+        dpq = queue_First(params,diskpartition_queue_t);
+	queue_Remove(dpq);
+	VOL_UNLOCK;
+	diskP = dpq->diskP;
+	free(dpq);
+
+	Log("Partition %s: attaching volumes\n", diskP->name);
+	dirp = opendir(VPartitionPath(diskP));
+	assert(dirp);
+	while ((dp = readdir(dirp))) {
+	    char *p;
+	    p = strrchr(dp->d_name, '.');
+	    if (p != NULL && strcmp(p, VHDREXT) == 0) {
+	        Error error;
+		Volume *vp;
+		vp = VAttachVolumeByName(&error, diskP->name, dp->d_name,
+					 V_VOLUPD);
+		(*(vp ? &nAttached : &nUnattached))++;
+		if (error == VOFFLINE)
+		    Log("Volume %d stays offline (/vice/offline/%s exists)\n", VolumeNumber(dp->d_name), dp->d_name);
+		else if (LogLevel >= 5) {
+		    Log("Partition %s: attached volume %d (%s)\n",
+			diskP->name, VolumeNumber(dp->d_name),
+			dp->d_name);
+		}
+		if (vp) {
+		    VPutVolume(vp);
+		}
+	    }
+	}
+	Log("Partition %s: attached %d volumes; %d volumes not attached\n", diskP->name, nAttached, nUnattached);
+	closedir(dirp);
+	VOL_LOCK;
+    }
+
+    params->n_threads_complete++;
+    pthread_cond_signal(&params->thread_done_cv);
+    VOL_UNLOCK;
+    return NULL;
+}
+#endif /* AFS_PTHREAD_ENV */
+
 /* This must be called by any volume utility which needs to run while the
    file server is also running.  This is separated from VInitVolumePackage so
    that a utility can fork--and each of the children can independently
@@ -339,8 +456,10 @@ int
 VConnectFS(void)
 {
     int retVal;
-    VOL_LOCK retVal = VConnectFS_r();
-    VOL_UNLOCK return retVal;
+    VOL_LOCK;
+    retVal = VConnectFS_r();
+    VOL_UNLOCK;
+    return retVal;
 }
 
 int
@@ -365,8 +484,10 @@ VDisconnectFS_r(void)
 void
 VDisconnectFS(void)
 {
-    VOL_LOCK VDisconnectFS_r();
-VOL_UNLOCK}
+    VOL_LOCK;
+    VDisconnectFS_r();
+    VOL_UNLOCK;
+}
 
 void
 VShutdown_r(void)
@@ -409,8 +530,10 @@ VShutdown_r(void)
 void
 VShutdown(void)
 {
-    VOL_LOCK VShutdown_r();
-VOL_UNLOCK}
+    VOL_LOCK;
+    VShutdown_r();
+    VOL_UNLOCK;
+}
 
 
 static void
@@ -556,9 +679,12 @@ Volume *
 VAttachVolumeByName(Error * ec, char *partition, char *name, int mode)
 {
     Volume *retVal;
-    VATTACH_LOCK VOL_LOCK retVal =
-	VAttachVolumeByName_r(ec, partition, name, mode);
-    VOL_UNLOCK VATTACH_UNLOCK return retVal;
+    VATTACH_LOCK;
+    VOL_LOCK;
+    retVal = VAttachVolumeByName_r(ec, partition, name, mode);
+    VOL_UNLOCK;
+    VATTACH_UNLOCK;
+    return retVal;
 }
 
 Volume *
@@ -601,18 +727,20 @@ VAttachVolumeByName_r(Error * ec, char *partition, char *name, int mode)
     strcpy(path, VPartitionPath(partp));
     strcat(path, "/");
     strcat(path, name);
-    VOL_UNLOCK if ((fd = afs_open(path, O_RDONLY)) == -1
-		   || afs_fstat(fd, &status) == -1) {
+    VOL_UNLOCK;
+    if ((fd = afs_open(path, O_RDONLY)) == -1 || afs_fstat(fd, &status) == -1) {
 	Log("VAttachVolume: Failed to open %s (errno %d)\n", path, errno);
 	if (fd > -1)
 	    close(fd);
-	VOL_LOCK *ec = VNOVOL;
+	VOL_LOCK;
+	*ec = VNOVOL;
 	goto done;
     }
     n = read(fd, &diskHeader, sizeof(diskHeader));
     close(fd);
-    VOL_LOCK if (n != sizeof(diskHeader)
-		 || diskHeader.stamp.magic != VOLUMEHEADERMAGIC) {
+    VOL_LOCK;
+    if (n != sizeof(diskHeader)
+	|| diskHeader.stamp.magic != VOLUMEHEADERMAGIC) {
 	Log("VAttachVolume: Error reading volume header %s\n", path);
 	*ec = VSALVAGE;
 	goto done;
@@ -624,7 +752,7 @@ VAttachVolumeByName_r(Error * ec, char *partition, char *name, int mode)
     }
 
     DiskToVolumeHeader(&iheader, &diskHeader);
-    if (programType == volumeUtility && mode != V_SECRETLY) {
+    if (programType == volumeUtility && mode != V_SECRETLY && mode != V_PEEK) {
 	if (FSYNC_askfs(iheader.id, partition, FSYNC_NEEDVOLUME, mode)
 	    == FSYNC_DENIED) {
 	    Log("VAttachVolume: attach of volume %u apparently denied by file server\n", iheader.id);
@@ -639,7 +767,7 @@ VAttachVolumeByName_r(Error * ec, char *partition, char *name, int mode)
 	 * takes the volume offline or not.  If the volume isn't
 	 * offline, we must not return it when we detach the volume,
 	 * or the server will abort */
-	if (mode == V_READONLY
+	if (mode == V_READONLY || mode == V_PEEK
 	    || (!VolumeWriteable(vp) && (mode == V_CLONE || mode == V_DUMP)))
 	    vp->needsPutBack = 0;
 	else
@@ -656,7 +784,8 @@ VAttachVolumeByName_r(Error * ec, char *partition, char *name, int mode)
      * for all of that to happen, but if it does, probably the right
      * fix is for the server to allow the return of readonly volumes
      * that it doesn't think are really checked out. */
-    if (programType == volumeUtility && vp == NULL && mode != V_SECRETLY) {
+    if (programType == volumeUtility && vp == NULL &&
+	mode != V_SECRETLY && mode != V_PEEK) {
 	FSYNC_askfs(iheader.id, partition, FSYNC_ON, 0);
     } else if (programType == fileServer && vp) {
 	V_needsCallback(vp) = 0;
@@ -711,7 +840,9 @@ attach2(Error * ec, char *path, register struct VolumeHeader * header,
 {
     register Volume *vp;
 
-    VOL_UNLOCK vp = (Volume *) calloc(1, sizeof(Volume));
+    VOL_UNLOCK;
+
+    vp = (Volume *) calloc(1, sizeof(Volume));
     assert(vp != NULL);
     vp->specialStatus = (byte) (isbusy ? VBUSY : 0);
     vp->device = partp->device;
@@ -723,18 +854,23 @@ attach2(Error * ec, char *path, register struct VolumeHeader * header,
     IH_INIT(vp->diskDataHandle, partp->device, header->parent,
 	    header->volumeInfo);
     IH_INIT(vp->linkHandle, partp->device, header->parent, header->linkTable);
+    vp->shuttingDown = 0;
+    vp->goingOffline = 0;
+    vp->nUsers = 1;
+
+    VOL_LOCK;
     vp->cacheCheck = ++VolumeCacheCheck;
     /* just in case this ever rolls over */
     if (!vp->cacheCheck)
 	vp->cacheCheck = ++VolumeCacheCheck;
-    vp->shuttingDown = 0;
-    vp->goingOffline = 0;
-    vp->nUsers = 1;
-    VOL_LOCK GetVolumeHeader(vp);
-    VOL_UNLOCK(void) ReadHeader(ec, V_diskDataHandle(vp), (char *)&V_disk(vp),
-				sizeof(V_disk(vp)), VOLUMEINFOMAGIC,
-				VOLUMEINFOVERSION);
-    VOL_LOCK if (*ec) {
+    GetVolumeHeader(vp);
+    VOL_UNLOCK;
+
+    (void)ReadHeader(ec, V_diskDataHandle(vp), (char *)&V_disk(vp),
+		     sizeof(V_disk(vp)), VOLUMEINFOMAGIC, VOLUMEINFOVERSION);
+
+    VOL_LOCK;
+    if (*ec) {
 	Log("VAttachVolume: Error reading diskDataHandle vol header %s; error=%u\n", path, *ec);
     }
     if (!*ec) {
@@ -751,29 +887,34 @@ attach2(Error * ec, char *path, register struct VolumeHeader * header,
 	    V_stat_initialized(vp) = 1;
 	}
 #endif /* OPENAFS_VOL_STATS */
-	VOL_UNLOCK(void) ReadHeader(ec, vp->vnodeIndex[vSmall].handle,
-				    (char *)&iHead, sizeof(iHead),
-				    SMALLINDEXMAGIC, SMALLINDEXVERSION);
-	VOL_LOCK if (*ec) {
+	VOL_UNLOCK;
+	(void)ReadHeader(ec, vp->vnodeIndex[vSmall].handle,
+			 (char *)&iHead, sizeof(iHead),
+			 SMALLINDEXMAGIC, SMALLINDEXVERSION);
+	VOL_LOCK;
+	if (*ec) {
 	    Log("VAttachVolume: Error reading smallVnode vol header %s; error=%u\n", path, *ec);
 	}
     }
     if (!*ec) {
 	struct IndexFileHeader iHead;
-	VOL_UNLOCK(void) ReadHeader(ec, vp->vnodeIndex[vLarge].handle,
-				    (char *)&iHead, sizeof(iHead),
-				    LARGEINDEXMAGIC, LARGEINDEXVERSION);
-	VOL_LOCK if (*ec) {
+	VOL_UNLOCK;
+	(void)ReadHeader(ec, vp->vnodeIndex[vLarge].handle,
+			 (char *)&iHead, sizeof(iHead),
+			 LARGEINDEXMAGIC, LARGEINDEXVERSION);
+	VOL_LOCK;
+	if (*ec) {
 	    Log("VAttachVolume: Error reading largeVnode vol header %s; error=%u\n", path, *ec);
 	}
     }
 #ifdef AFS_NAMEI_ENV
     if (!*ec) {
 	struct versionStamp stamp;
-	VOL_UNLOCK(void) ReadHeader(ec, V_linkHandle(vp), (char *)&stamp,
-				    sizeof(stamp), LINKTABLEMAGIC,
-				    LINKTABLEVERSION);
-	VOL_LOCK if (*ec) {
+	VOL_UNLOCK;
+	(void)ReadHeader(ec, V_linkHandle(vp), (char *)&stamp,
+			 sizeof(stamp), LINKTABLEMAGIC, LINKTABLEVERSION);
+	VOL_LOCK;
+	if (*ec) {
 	    Log("VAttachVolume: Error reading namei vol header %s; error=%u\n", path, *ec);
 	}
     }
@@ -788,6 +929,7 @@ attach2(Error * ec, char *path, register struct VolumeHeader * header,
 	    vp->specialStatus = 0;
 	Log("VAttachVolume: volume salvage flag is ON for %s; volume needs salvage\n", path);
 	*ec = VSALVAGE;
+	FreeVolume(vp);
 	return NULL;
     }
     if (programType == fileServer) {
@@ -818,8 +960,10 @@ attach2(Error * ec, char *path, register struct VolumeHeader * header,
     if (programType == fileServer && VolumeWriteable(vp)) {
 	int i;
 	for (i = 0; i < nVNODECLASSES; i++) {
-	    VOL_UNLOCK GetBitmap(ec, vp, i);
-	    VOL_LOCK if (*ec) {
+	    VOL_UNLOCK;
+	    GetBitmap(ec, vp, i);
+	    VOL_LOCK;
+	    if (*ec) {
 		FreeVolume(vp);
 		Log("VAttachVolume: error getting bitmap for volume (%s)\n",
 		    path);
@@ -850,8 +994,12 @@ Volume *
 VAttachVolume(Error * ec, VolumeId volumeId, int mode)
 {
     Volume *retVal;
-    VATTACH_LOCK VOL_LOCK retVal = VAttachVolume_r(ec, volumeId, mode);
-    VOL_UNLOCK VATTACH_UNLOCK return retVal;
+    VATTACH_LOCK;
+    VOL_LOCK;
+    retVal = VAttachVolume_r(ec, volumeId, mode);
+    VOL_UNLOCK;
+    VATTACH_UNLOCK;
+    return retVal;
 }
 
 Volume *
@@ -900,8 +1048,10 @@ static int
 VHold(register Volume * vp)
 {
     int retVal;
-    VOL_LOCK retVal = VHold_r(vp);
-    VOL_UNLOCK return retVal;
+    VOL_LOCK;
+    retVal = VHold_r(vp);
+    VOL_UNLOCK;
+    return retVal;
 }
 
 void
@@ -916,8 +1066,10 @@ VTakeOffline_r(register Volume * vp)
 void
 VTakeOffline(register Volume * vp)
 {
-    VOL_LOCK VTakeOffline_r(vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VTakeOffline_r(vp);
+    VOL_UNLOCK;
+}
 
 void
 VPutVolume_r(register Volume * vp)
@@ -961,8 +1113,10 @@ VPutVolume_r(register Volume * vp)
 void
 VPutVolume(register Volume * vp)
 {
-    VOL_LOCK VPutVolume_r(vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VPutVolume_r(vp);
+    VOL_UNLOCK;
+}
 
 /* Get a pointer to an attached volume.  The pointer is returned regardless
    of whether or not the volume is in service or on/off line.  An error
@@ -971,8 +1125,10 @@ Volume *
 VGetVolume(Error * ec, VolId volumeId)
 {
     Volume *retVal;
-    VOL_LOCK retVal = VGetVolume_r(ec, volumeId);
-    VOL_UNLOCK return retVal;
+    VOL_LOCK;
+    retVal = VGetVolume_r(ec, volumeId);
+    VOL_UNLOCK;
+    return retVal;
 }
 
 Volume *
@@ -1024,7 +1180,7 @@ VGetVolume_r(Error * ec, VolId volumeId)
 		    Log("Volume %u: couldn't reread volume header\n",
 			vp->hashid);
 		FreeVolume(vp);
-		vp = 0;
+		vp = NULL;
 		break;
 	    }
 	}
@@ -1032,7 +1188,7 @@ VGetVolume_r(Error * ec, VolId volumeId)
 	if (vp->shuttingDown) {
 	    V8++;
 	    *ec = VNOVOL;
-	    vp = 0;
+	    vp = NULL;
 	    break;
 	}
 	if (programType == fileServer) {
@@ -1125,8 +1281,10 @@ VForceOffline_r(Volume * vp)
 void
 VForceOffline(Volume * vp)
 {
-    VOL_LOCK VForceOffline_r(vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VForceOffline_r(vp);
+    VOL_UNLOCK;
+}
 
 /* The opposite of VAttachVolume.  The volume header is written to disk, with
    the inUse bit turned off.  A copy of the header is maintained in memory,
@@ -1155,8 +1313,10 @@ VOffline_r(Volume * vp, char *message)
 void
 VOffline(Volume * vp, char *message)
 {
-    VOL_LOCK VOffline_r(vp, message);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VOffline_r(vp, message);
+    VOL_UNLOCK;
+}
 
 /* For VDetachVolume, we close all cached file descriptors, but keep
  * the Inode handles in case we need to read from a busy volume.
@@ -1236,8 +1396,10 @@ VDetachVolume_r(Error * ec, Volume * vp)
 void
 VDetachVolume(Error * ec, Volume * vp)
 {
-    VOL_LOCK VDetachVolume_r(ec, vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VDetachVolume_r(ec, vp);
+    VOL_UNLOCK;
+}
 
 
 VnodeId
@@ -1261,19 +1423,23 @@ VAllocBitmapEntry_r(Error * ec, Volume * vp, register struct vnodeIndex
 					 * from AddNewReadableResidency */
 		wasVBUSY = 1;
 	    } else {
-		VOL_UNLOCK while (vp->specialStatus == VBUSY)
+		VOL_UNLOCK;
+		while (vp->specialStatus == VBUSY)
 #ifdef AFS_PTHREAD_ENV
 		    sleep(2);
 #else /* AFS_PTHREAD_ENV */
 		    IOMGR_Sleep(2);
 #endif /* AFS_PTHREAD_ENV */
-	    VOL_LOCK}
+		VOL_LOCK;
+	    }
 	}
 	if (!index->bitmap) {
 	    vp->specialStatus = VBUSY;	/* Stop anyone else from using it. */
 	    for (i = 0; i < nVNODECLASSES; i++) {
-		VOL_UNLOCK GetBitmap(ec, vp, i);
-		VOL_LOCK if (*ec) {
+		VOL_UNLOCK;
+		GetBitmap(ec, vp, i);
+		VOL_LOCK;
+		if (*ec) {
 		    vp->specialStatus = 0;
 		    vp->shuttingDown = 1;	/* Let who has it free it. */
 		    return NULL;
@@ -1315,8 +1481,10 @@ VnodeId
 VAllocBitmapEntry(Error * ec, Volume * vp, register struct vnodeIndex * index)
 {
     VnodeId retVal;
-    VOL_LOCK retVal = VAllocBitmapEntry_r(ec, vp, index);
-    VOL_UNLOCK return retVal;
+    VOL_LOCK;
+    retVal = VAllocBitmapEntry_r(ec, vp, index);
+    VOL_UNLOCK;
+    return retVal;
 }
 
 void
@@ -1343,8 +1511,10 @@ void
 VFreeBitMapEntry(Error * ec, register struct vnodeIndex *index,
 		 unsigned bitNumber)
 {
-    VOL_LOCK VFreeBitMapEntry_r(ec, index, bitNumber);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VFreeBitMapEntry_r(ec, index, bitNumber);
+    VOL_UNLOCK;
+}
 
 void
 VUpdateVolume_r(Error * ec, Volume * vp)
@@ -1366,8 +1536,10 @@ VUpdateVolume_r(Error * ec, Volume * vp)
 void
 VUpdateVolume(Error * ec, Volume * vp)
 {
-    VOL_LOCK VUpdateVolume_r(ec, vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VUpdateVolume_r(ec, vp);
+    VOL_UNLOCK;
+}
 
 void
 VSyncVolume_r(Error * ec, Volume * vp)
@@ -1387,8 +1559,10 @@ VSyncVolume_r(Error * ec, Volume * vp)
 void
 VSyncVolume(Error * ec, Volume * vp)
 {
-    VOL_LOCK VSyncVolume_r(ec, vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VSyncVolume_r(ec, vp);
+    VOL_UNLOCK;
+}
 
 static void
 FreeVolume(Volume * vp)
@@ -1608,8 +1782,10 @@ int
 VAdjustVolumeStatistics(register Volume * vp)
 {
     int retVal;
-    VOL_LOCK retVal = VAdjustVolumeStatistics_r(vp);
-    VOL_UNLOCK return retVal;
+    VOL_LOCK;
+    retVal = VAdjustVolumeStatistics_r(vp);
+    VOL_UNLOCK;
+    return retVal;
 }
 
 void
@@ -1630,8 +1806,10 @@ VBumpVolumeUsage_r(register Volume * vp)
 void
 VBumpVolumeUsage(register Volume * vp)
 {
-    VOL_LOCK VBumpVolumeUsage_r(vp);
-VOL_UNLOCK}
+    VOL_LOCK;
+    VBumpVolumeUsage_r(vp);
+    VOL_UNLOCK;
+}
 
 void
 VSetDiskUsage_r(void)
@@ -1659,8 +1837,10 @@ VSetDiskUsage_r(void)
 void
 VSetDiskUsage(void)
 {
-    VOL_LOCK VSetDiskUsage_r();
-VOL_UNLOCK}
+    VOL_LOCK;
+    VSetDiskUsage_r();
+    VOL_UNLOCK;
+}
 
 /* The number of minutes that a volume hasn't been updated before the
  * "Dont salvage" flag in the volume header will be turned on */
@@ -1751,11 +1931,11 @@ GetVolumeHeader(register Volume * vp)
     int old;
     static int everLogged = 0;
 
-    old = (vp->header != 0);	/* old == volume already has a header */
+    old = (vp->header != NULL);	/* old == volume already has a header */
     if (programType != fileServer) {
 	if (!vp->header) {
 	    hd = (struct volHeader *)calloc(1, sizeof(*vp->header));
-	    assert(hd != 0);
+	    assert(hd != NULL);
 	    vp->header = hd;
 	    hd->back = vp;
 	}
@@ -1882,5 +2062,8 @@ VPrintCacheStats_r(void)
 void
 VPrintCacheStats(void)
 {
-    VOL_LOCK VPrintCacheStats_r();
-VOL_UNLOCK}
+    VOL_LOCK;
+    VPrintCacheStats_r();
+    VOL_UNLOCK;
+}
+
